# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DatabaseMysqlConfigArgs', 'DatabaseMysqlConfig']

@pulumi.input_type
class DatabaseMysqlConfigArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[_builtins.str],
                 backup_hour: Optional[pulumi.Input[_builtins.int]] = None,
                 backup_minute: Optional[pulumi.Input[_builtins.int]] = None,
                 binlog_retention_period: Optional[pulumi.Input[_builtins.int]] = None,
                 connect_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 default_time_zone: Optional[pulumi.Input[_builtins.str]] = None,
                 group_concat_max_len: Optional[pulumi.Input[_builtins.int]] = None,
                 information_schema_stats_expiry: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_ft_min_token_size: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_ft_server_stopword_table: Optional[pulumi.Input[_builtins.str]] = None,
                 innodb_lock_wait_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_log_buffer_size: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_online_alter_log_max_size: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_print_all_deadlocks: Optional[pulumi.Input[_builtins.bool]] = None,
                 innodb_rollback_on_timeout: Optional[pulumi.Input[_builtins.bool]] = None,
                 interactive_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 internal_tmp_mem_storage_engine: Optional[pulumi.Input[_builtins.str]] = None,
                 long_query_time: Optional[pulumi.Input[_builtins.float]] = None,
                 max_allowed_packet: Optional[pulumi.Input[_builtins.int]] = None,
                 max_heap_table_size: Optional[pulumi.Input[_builtins.int]] = None,
                 net_read_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 net_write_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 slow_query_log: Optional[pulumi.Input[_builtins.bool]] = None,
                 sort_buffer_size: Optional[pulumi.Input[_builtins.int]] = None,
                 sql_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 sql_require_primary_key: Optional[pulumi.Input[_builtins.bool]] = None,
                 tmp_table_size: Optional[pulumi.Input[_builtins.int]] = None,
                 wait_timeout: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a DatabaseMysqlConfig resource.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the target MySQL cluster.
        :param pulumi.Input[_builtins.int] backup_hour: The hour of day (in UTC) when backup for the service starts. New backup only starts if previous backup has already completed.
        :param pulumi.Input[_builtins.int] backup_minute: The minute of the backup hour when backup for the service starts. New backup only starts if previous backup has already completed.
        :param pulumi.Input[_builtins.int] binlog_retention_period: The minimum amount of time, in seconds, to keep binlog entries before deletion. This may be extended for services that require binlog entries for longer than the default, for example if using the MySQL Debezium Kafka connector.
        :param pulumi.Input[_builtins.int] connect_timeout: The number of seconds that the mysqld server waits for a connect packet before responding with bad handshake.
        :param pulumi.Input[_builtins.str] default_time_zone: Default server time zone, in the form of an offset from UTC (from -12:00 to +12:00), a time zone name (EST), or `SYSTEM` to use the MySQL server default.
        :param pulumi.Input[_builtins.int] group_concat_max_len: The maximum permitted result length, in bytes, for the `GROUP_CONCAT()` function.
        :param pulumi.Input[_builtins.int] information_schema_stats_expiry: The time, in seconds, before cached statistics expire.
        :param pulumi.Input[_builtins.int] innodb_ft_min_token_size: The minimum length of words that an InnoDB FULLTEXT index stores.
        :param pulumi.Input[_builtins.str] innodb_ft_server_stopword_table: The InnoDB FULLTEXT index stopword list for all InnoDB tables.
        :param pulumi.Input[_builtins.int] innodb_lock_wait_timeout: The time, in seconds, that an InnoDB transaction waits for a row lock. before giving up.
        :param pulumi.Input[_builtins.int] innodb_log_buffer_size: The size of the buffer, in bytes, that InnoDB uses to write to the log files. on disk.
        :param pulumi.Input[_builtins.int] innodb_online_alter_log_max_size: The upper limit, in bytes, of the size of the temporary log files used during online DDL operations for InnoDB tables.
        :param pulumi.Input[_builtins.bool] innodb_print_all_deadlocks: When enabled, records information about all deadlocks in InnoDB user transactions in the error log. Disabled by default.
        :param pulumi.Input[_builtins.bool] innodb_rollback_on_timeout: When enabled, transaction timeouts cause InnoDB to abort and roll back the entire transaction.
        :param pulumi.Input[_builtins.int] interactive_timeout: The time, in seconds, the server waits for activity on an interactive. connection before closing it.
        :param pulumi.Input[_builtins.str] internal_tmp_mem_storage_engine: The storage engine for in-memory internal temporary tables. Supported values are: `TempTable`, `MEMORY`.
        :param pulumi.Input[_builtins.float] long_query_time: The time, in seconds, for a query to take to execute before being captured by `slow_query_logs`. Default is `10` seconds.
        :param pulumi.Input[_builtins.int] max_allowed_packet: The size of the largest message, in bytes, that can be received by the server. Default is `67108864` (64M).
        :param pulumi.Input[_builtins.int] max_heap_table_size: The maximum size, in bytes, of internal in-memory tables. Also set `tmp_table_size`. Default is `16777216` (16M)
        :param pulumi.Input[_builtins.int] net_read_timeout: The time, in seconds, to wait for more data from an existing connection. aborting the read.
        :param pulumi.Input[_builtins.int] net_write_timeout: The number of seconds to wait for a block to be written to a connection before aborting the write.
        :param pulumi.Input[_builtins.bool] slow_query_log: When enabled, captures slow queries. When disabled, also truncates the mysql.slow_log table. Default is false.
        :param pulumi.Input[_builtins.int] sort_buffer_size: The sort buffer size, in bytes, for `ORDER BY` optimization. Default is `262144`. (256K).
        :param pulumi.Input[_builtins.str] sql_mode: Global SQL mode. If empty, uses MySQL server defaults. Must only include uppercase alphabetic characters, underscores, and commas.
        :param pulumi.Input[_builtins.bool] sql_require_primary_key: Require primary key to be defined for new tables or old tables modified with ALTER TABLE and fail if missing. It is recommended to always have primary keys because various functionality may break if any large table is missing them.
        :param pulumi.Input[_builtins.int] tmp_table_size: The maximum size, in bytes, of internal in-memory tables. Also set `max_heap_table_size`. Default is `16777216` (16M).
        :param pulumi.Input[_builtins.int] wait_timeout: The number of seconds the server waits for activity on a noninteractive connection before closing it.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        if backup_hour is not None:
            pulumi.set(__self__, "backup_hour", backup_hour)
        if backup_minute is not None:
            pulumi.set(__self__, "backup_minute", backup_minute)
        if binlog_retention_period is not None:
            pulumi.set(__self__, "binlog_retention_period", binlog_retention_period)
        if connect_timeout is not None:
            pulumi.set(__self__, "connect_timeout", connect_timeout)
        if default_time_zone is not None:
            pulumi.set(__self__, "default_time_zone", default_time_zone)
        if group_concat_max_len is not None:
            pulumi.set(__self__, "group_concat_max_len", group_concat_max_len)
        if information_schema_stats_expiry is not None:
            pulumi.set(__self__, "information_schema_stats_expiry", information_schema_stats_expiry)
        if innodb_ft_min_token_size is not None:
            pulumi.set(__self__, "innodb_ft_min_token_size", innodb_ft_min_token_size)
        if innodb_ft_server_stopword_table is not None:
            pulumi.set(__self__, "innodb_ft_server_stopword_table", innodb_ft_server_stopword_table)
        if innodb_lock_wait_timeout is not None:
            pulumi.set(__self__, "innodb_lock_wait_timeout", innodb_lock_wait_timeout)
        if innodb_log_buffer_size is not None:
            pulumi.set(__self__, "innodb_log_buffer_size", innodb_log_buffer_size)
        if innodb_online_alter_log_max_size is not None:
            pulumi.set(__self__, "innodb_online_alter_log_max_size", innodb_online_alter_log_max_size)
        if innodb_print_all_deadlocks is not None:
            pulumi.set(__self__, "innodb_print_all_deadlocks", innodb_print_all_deadlocks)
        if innodb_rollback_on_timeout is not None:
            pulumi.set(__self__, "innodb_rollback_on_timeout", innodb_rollback_on_timeout)
        if interactive_timeout is not None:
            pulumi.set(__self__, "interactive_timeout", interactive_timeout)
        if internal_tmp_mem_storage_engine is not None:
            pulumi.set(__self__, "internal_tmp_mem_storage_engine", internal_tmp_mem_storage_engine)
        if long_query_time is not None:
            pulumi.set(__self__, "long_query_time", long_query_time)
        if max_allowed_packet is not None:
            pulumi.set(__self__, "max_allowed_packet", max_allowed_packet)
        if max_heap_table_size is not None:
            pulumi.set(__self__, "max_heap_table_size", max_heap_table_size)
        if net_read_timeout is not None:
            pulumi.set(__self__, "net_read_timeout", net_read_timeout)
        if net_write_timeout is not None:
            pulumi.set(__self__, "net_write_timeout", net_write_timeout)
        if slow_query_log is not None:
            pulumi.set(__self__, "slow_query_log", slow_query_log)
        if sort_buffer_size is not None:
            pulumi.set(__self__, "sort_buffer_size", sort_buffer_size)
        if sql_mode is not None:
            pulumi.set(__self__, "sql_mode", sql_mode)
        if sql_require_primary_key is not None:
            pulumi.set(__self__, "sql_require_primary_key", sql_require_primary_key)
        if tmp_table_size is not None:
            pulumi.set(__self__, "tmp_table_size", tmp_table_size)
        if wait_timeout is not None:
            pulumi.set(__self__, "wait_timeout", wait_timeout)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the target MySQL cluster.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="backupHour")
    def backup_hour(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The hour of day (in UTC) when backup for the service starts. New backup only starts if previous backup has already completed.
        """
        return pulumi.get(self, "backup_hour")

    @backup_hour.setter
    def backup_hour(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "backup_hour", value)

    @_builtins.property
    @pulumi.getter(name="backupMinute")
    def backup_minute(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minute of the backup hour when backup for the service starts. New backup only starts if previous backup has already completed.
        """
        return pulumi.get(self, "backup_minute")

    @backup_minute.setter
    def backup_minute(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "backup_minute", value)

    @_builtins.property
    @pulumi.getter(name="binlogRetentionPeriod")
    def binlog_retention_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum amount of time, in seconds, to keep binlog entries before deletion. This may be extended for services that require binlog entries for longer than the default, for example if using the MySQL Debezium Kafka connector.
        """
        return pulumi.get(self, "binlog_retention_period")

    @binlog_retention_period.setter
    def binlog_retention_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "binlog_retention_period", value)

    @_builtins.property
    @pulumi.getter(name="connectTimeout")
    def connect_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of seconds that the mysqld server waits for a connect packet before responding with bad handshake.
        """
        return pulumi.get(self, "connect_timeout")

    @connect_timeout.setter
    def connect_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "connect_timeout", value)

    @_builtins.property
    @pulumi.getter(name="defaultTimeZone")
    def default_time_zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default server time zone, in the form of an offset from UTC (from -12:00 to +12:00), a time zone name (EST), or `SYSTEM` to use the MySQL server default.
        """
        return pulumi.get(self, "default_time_zone")

    @default_time_zone.setter
    def default_time_zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_time_zone", value)

    @_builtins.property
    @pulumi.getter(name="groupConcatMaxLen")
    def group_concat_max_len(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum permitted result length, in bytes, for the `GROUP_CONCAT()` function.
        """
        return pulumi.get(self, "group_concat_max_len")

    @group_concat_max_len.setter
    def group_concat_max_len(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "group_concat_max_len", value)

    @_builtins.property
    @pulumi.getter(name="informationSchemaStatsExpiry")
    def information_schema_stats_expiry(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The time, in seconds, before cached statistics expire.
        """
        return pulumi.get(self, "information_schema_stats_expiry")

    @information_schema_stats_expiry.setter
    def information_schema_stats_expiry(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "information_schema_stats_expiry", value)

    @_builtins.property
    @pulumi.getter(name="innodbFtMinTokenSize")
    def innodb_ft_min_token_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum length of words that an InnoDB FULLTEXT index stores.
        """
        return pulumi.get(self, "innodb_ft_min_token_size")

    @innodb_ft_min_token_size.setter
    def innodb_ft_min_token_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "innodb_ft_min_token_size", value)

    @_builtins.property
    @pulumi.getter(name="innodbFtServerStopwordTable")
    def innodb_ft_server_stopword_table(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The InnoDB FULLTEXT index stopword list for all InnoDB tables.
        """
        return pulumi.get(self, "innodb_ft_server_stopword_table")

    @innodb_ft_server_stopword_table.setter
    def innodb_ft_server_stopword_table(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "innodb_ft_server_stopword_table", value)

    @_builtins.property
    @pulumi.getter(name="innodbLockWaitTimeout")
    def innodb_lock_wait_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The time, in seconds, that an InnoDB transaction waits for a row lock. before giving up.
        """
        return pulumi.get(self, "innodb_lock_wait_timeout")

    @innodb_lock_wait_timeout.setter
    def innodb_lock_wait_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "innodb_lock_wait_timeout", value)

    @_builtins.property
    @pulumi.getter(name="innodbLogBufferSize")
    def innodb_log_buffer_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The size of the buffer, in bytes, that InnoDB uses to write to the log files. on disk.
        """
        return pulumi.get(self, "innodb_log_buffer_size")

    @innodb_log_buffer_size.setter
    def innodb_log_buffer_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "innodb_log_buffer_size", value)

    @_builtins.property
    @pulumi.getter(name="innodbOnlineAlterLogMaxSize")
    def innodb_online_alter_log_max_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The upper limit, in bytes, of the size of the temporary log files used during online DDL operations for InnoDB tables.
        """
        return pulumi.get(self, "innodb_online_alter_log_max_size")

    @innodb_online_alter_log_max_size.setter
    def innodb_online_alter_log_max_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "innodb_online_alter_log_max_size", value)

    @_builtins.property
    @pulumi.getter(name="innodbPrintAllDeadlocks")
    def innodb_print_all_deadlocks(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When enabled, records information about all deadlocks in InnoDB user transactions in the error log. Disabled by default.
        """
        return pulumi.get(self, "innodb_print_all_deadlocks")

    @innodb_print_all_deadlocks.setter
    def innodb_print_all_deadlocks(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "innodb_print_all_deadlocks", value)

    @_builtins.property
    @pulumi.getter(name="innodbRollbackOnTimeout")
    def innodb_rollback_on_timeout(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When enabled, transaction timeouts cause InnoDB to abort and roll back the entire transaction.
        """
        return pulumi.get(self, "innodb_rollback_on_timeout")

    @innodb_rollback_on_timeout.setter
    def innodb_rollback_on_timeout(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "innodb_rollback_on_timeout", value)

    @_builtins.property
    @pulumi.getter(name="interactiveTimeout")
    def interactive_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The time, in seconds, the server waits for activity on an interactive. connection before closing it.
        """
        return pulumi.get(self, "interactive_timeout")

    @interactive_timeout.setter
    def interactive_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "interactive_timeout", value)

    @_builtins.property
    @pulumi.getter(name="internalTmpMemStorageEngine")
    def internal_tmp_mem_storage_engine(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The storage engine for in-memory internal temporary tables. Supported values are: `TempTable`, `MEMORY`.
        """
        return pulumi.get(self, "internal_tmp_mem_storage_engine")

    @internal_tmp_mem_storage_engine.setter
    def internal_tmp_mem_storage_engine(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "internal_tmp_mem_storage_engine", value)

    @_builtins.property
    @pulumi.getter(name="longQueryTime")
    def long_query_time(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        The time, in seconds, for a query to take to execute before being captured by `slow_query_logs`. Default is `10` seconds.
        """
        return pulumi.get(self, "long_query_time")

    @long_query_time.setter
    def long_query_time(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "long_query_time", value)

    @_builtins.property
    @pulumi.getter(name="maxAllowedPacket")
    def max_allowed_packet(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The size of the largest message, in bytes, that can be received by the server. Default is `67108864` (64M).
        """
        return pulumi.get(self, "max_allowed_packet")

    @max_allowed_packet.setter
    def max_allowed_packet(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_allowed_packet", value)

    @_builtins.property
    @pulumi.getter(name="maxHeapTableSize")
    def max_heap_table_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum size, in bytes, of internal in-memory tables. Also set `tmp_table_size`. Default is `16777216` (16M)
        """
        return pulumi.get(self, "max_heap_table_size")

    @max_heap_table_size.setter
    def max_heap_table_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_heap_table_size", value)

    @_builtins.property
    @pulumi.getter(name="netReadTimeout")
    def net_read_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The time, in seconds, to wait for more data from an existing connection. aborting the read.
        """
        return pulumi.get(self, "net_read_timeout")

    @net_read_timeout.setter
    def net_read_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "net_read_timeout", value)

    @_builtins.property
    @pulumi.getter(name="netWriteTimeout")
    def net_write_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of seconds to wait for a block to be written to a connection before aborting the write.
        """
        return pulumi.get(self, "net_write_timeout")

    @net_write_timeout.setter
    def net_write_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "net_write_timeout", value)

    @_builtins.property
    @pulumi.getter(name="slowQueryLog")
    def slow_query_log(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When enabled, captures slow queries. When disabled, also truncates the mysql.slow_log table. Default is false.
        """
        return pulumi.get(self, "slow_query_log")

    @slow_query_log.setter
    def slow_query_log(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "slow_query_log", value)

    @_builtins.property
    @pulumi.getter(name="sortBufferSize")
    def sort_buffer_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The sort buffer size, in bytes, for `ORDER BY` optimization. Default is `262144`. (256K).
        """
        return pulumi.get(self, "sort_buffer_size")

    @sort_buffer_size.setter
    def sort_buffer_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "sort_buffer_size", value)

    @_builtins.property
    @pulumi.getter(name="sqlMode")
    def sql_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Global SQL mode. If empty, uses MySQL server defaults. Must only include uppercase alphabetic characters, underscores, and commas.
        """
        return pulumi.get(self, "sql_mode")

    @sql_mode.setter
    def sql_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sql_mode", value)

    @_builtins.property
    @pulumi.getter(name="sqlRequirePrimaryKey")
    def sql_require_primary_key(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Require primary key to be defined for new tables or old tables modified with ALTER TABLE and fail if missing. It is recommended to always have primary keys because various functionality may break if any large table is missing them.
        """
        return pulumi.get(self, "sql_require_primary_key")

    @sql_require_primary_key.setter
    def sql_require_primary_key(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "sql_require_primary_key", value)

    @_builtins.property
    @pulumi.getter(name="tmpTableSize")
    def tmp_table_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum size, in bytes, of internal in-memory tables. Also set `max_heap_table_size`. Default is `16777216` (16M).
        """
        return pulumi.get(self, "tmp_table_size")

    @tmp_table_size.setter
    def tmp_table_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "tmp_table_size", value)

    @_builtins.property
    @pulumi.getter(name="waitTimeout")
    def wait_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of seconds the server waits for activity on a noninteractive connection before closing it.
        """
        return pulumi.get(self, "wait_timeout")

    @wait_timeout.setter
    def wait_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "wait_timeout", value)


@pulumi.input_type
class _DatabaseMysqlConfigState:
    def __init__(__self__, *,
                 backup_hour: Optional[pulumi.Input[_builtins.int]] = None,
                 backup_minute: Optional[pulumi.Input[_builtins.int]] = None,
                 binlog_retention_period: Optional[pulumi.Input[_builtins.int]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 connect_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 default_time_zone: Optional[pulumi.Input[_builtins.str]] = None,
                 group_concat_max_len: Optional[pulumi.Input[_builtins.int]] = None,
                 information_schema_stats_expiry: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_ft_min_token_size: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_ft_server_stopword_table: Optional[pulumi.Input[_builtins.str]] = None,
                 innodb_lock_wait_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_log_buffer_size: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_online_alter_log_max_size: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_print_all_deadlocks: Optional[pulumi.Input[_builtins.bool]] = None,
                 innodb_rollback_on_timeout: Optional[pulumi.Input[_builtins.bool]] = None,
                 interactive_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 internal_tmp_mem_storage_engine: Optional[pulumi.Input[_builtins.str]] = None,
                 long_query_time: Optional[pulumi.Input[_builtins.float]] = None,
                 max_allowed_packet: Optional[pulumi.Input[_builtins.int]] = None,
                 max_heap_table_size: Optional[pulumi.Input[_builtins.int]] = None,
                 net_read_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 net_write_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 slow_query_log: Optional[pulumi.Input[_builtins.bool]] = None,
                 sort_buffer_size: Optional[pulumi.Input[_builtins.int]] = None,
                 sql_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 sql_require_primary_key: Optional[pulumi.Input[_builtins.bool]] = None,
                 tmp_table_size: Optional[pulumi.Input[_builtins.int]] = None,
                 wait_timeout: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering DatabaseMysqlConfig resources.
        :param pulumi.Input[_builtins.int] backup_hour: The hour of day (in UTC) when backup for the service starts. New backup only starts if previous backup has already completed.
        :param pulumi.Input[_builtins.int] backup_minute: The minute of the backup hour when backup for the service starts. New backup only starts if previous backup has already completed.
        :param pulumi.Input[_builtins.int] binlog_retention_period: The minimum amount of time, in seconds, to keep binlog entries before deletion. This may be extended for services that require binlog entries for longer than the default, for example if using the MySQL Debezium Kafka connector.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the target MySQL cluster.
        :param pulumi.Input[_builtins.int] connect_timeout: The number of seconds that the mysqld server waits for a connect packet before responding with bad handshake.
        :param pulumi.Input[_builtins.str] default_time_zone: Default server time zone, in the form of an offset from UTC (from -12:00 to +12:00), a time zone name (EST), or `SYSTEM` to use the MySQL server default.
        :param pulumi.Input[_builtins.int] group_concat_max_len: The maximum permitted result length, in bytes, for the `GROUP_CONCAT()` function.
        :param pulumi.Input[_builtins.int] information_schema_stats_expiry: The time, in seconds, before cached statistics expire.
        :param pulumi.Input[_builtins.int] innodb_ft_min_token_size: The minimum length of words that an InnoDB FULLTEXT index stores.
        :param pulumi.Input[_builtins.str] innodb_ft_server_stopword_table: The InnoDB FULLTEXT index stopword list for all InnoDB tables.
        :param pulumi.Input[_builtins.int] innodb_lock_wait_timeout: The time, in seconds, that an InnoDB transaction waits for a row lock. before giving up.
        :param pulumi.Input[_builtins.int] innodb_log_buffer_size: The size of the buffer, in bytes, that InnoDB uses to write to the log files. on disk.
        :param pulumi.Input[_builtins.int] innodb_online_alter_log_max_size: The upper limit, in bytes, of the size of the temporary log files used during online DDL operations for InnoDB tables.
        :param pulumi.Input[_builtins.bool] innodb_print_all_deadlocks: When enabled, records information about all deadlocks in InnoDB user transactions in the error log. Disabled by default.
        :param pulumi.Input[_builtins.bool] innodb_rollback_on_timeout: When enabled, transaction timeouts cause InnoDB to abort and roll back the entire transaction.
        :param pulumi.Input[_builtins.int] interactive_timeout: The time, in seconds, the server waits for activity on an interactive. connection before closing it.
        :param pulumi.Input[_builtins.str] internal_tmp_mem_storage_engine: The storage engine for in-memory internal temporary tables. Supported values are: `TempTable`, `MEMORY`.
        :param pulumi.Input[_builtins.float] long_query_time: The time, in seconds, for a query to take to execute before being captured by `slow_query_logs`. Default is `10` seconds.
        :param pulumi.Input[_builtins.int] max_allowed_packet: The size of the largest message, in bytes, that can be received by the server. Default is `67108864` (64M).
        :param pulumi.Input[_builtins.int] max_heap_table_size: The maximum size, in bytes, of internal in-memory tables. Also set `tmp_table_size`. Default is `16777216` (16M)
        :param pulumi.Input[_builtins.int] net_read_timeout: The time, in seconds, to wait for more data from an existing connection. aborting the read.
        :param pulumi.Input[_builtins.int] net_write_timeout: The number of seconds to wait for a block to be written to a connection before aborting the write.
        :param pulumi.Input[_builtins.bool] slow_query_log: When enabled, captures slow queries. When disabled, also truncates the mysql.slow_log table. Default is false.
        :param pulumi.Input[_builtins.int] sort_buffer_size: The sort buffer size, in bytes, for `ORDER BY` optimization. Default is `262144`. (256K).
        :param pulumi.Input[_builtins.str] sql_mode: Global SQL mode. If empty, uses MySQL server defaults. Must only include uppercase alphabetic characters, underscores, and commas.
        :param pulumi.Input[_builtins.bool] sql_require_primary_key: Require primary key to be defined for new tables or old tables modified with ALTER TABLE and fail if missing. It is recommended to always have primary keys because various functionality may break if any large table is missing them.
        :param pulumi.Input[_builtins.int] tmp_table_size: The maximum size, in bytes, of internal in-memory tables. Also set `max_heap_table_size`. Default is `16777216` (16M).
        :param pulumi.Input[_builtins.int] wait_timeout: The number of seconds the server waits for activity on a noninteractive connection before closing it.
        """
        if backup_hour is not None:
            pulumi.set(__self__, "backup_hour", backup_hour)
        if backup_minute is not None:
            pulumi.set(__self__, "backup_minute", backup_minute)
        if binlog_retention_period is not None:
            pulumi.set(__self__, "binlog_retention_period", binlog_retention_period)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if connect_timeout is not None:
            pulumi.set(__self__, "connect_timeout", connect_timeout)
        if default_time_zone is not None:
            pulumi.set(__self__, "default_time_zone", default_time_zone)
        if group_concat_max_len is not None:
            pulumi.set(__self__, "group_concat_max_len", group_concat_max_len)
        if information_schema_stats_expiry is not None:
            pulumi.set(__self__, "information_schema_stats_expiry", information_schema_stats_expiry)
        if innodb_ft_min_token_size is not None:
            pulumi.set(__self__, "innodb_ft_min_token_size", innodb_ft_min_token_size)
        if innodb_ft_server_stopword_table is not None:
            pulumi.set(__self__, "innodb_ft_server_stopword_table", innodb_ft_server_stopword_table)
        if innodb_lock_wait_timeout is not None:
            pulumi.set(__self__, "innodb_lock_wait_timeout", innodb_lock_wait_timeout)
        if innodb_log_buffer_size is not None:
            pulumi.set(__self__, "innodb_log_buffer_size", innodb_log_buffer_size)
        if innodb_online_alter_log_max_size is not None:
            pulumi.set(__self__, "innodb_online_alter_log_max_size", innodb_online_alter_log_max_size)
        if innodb_print_all_deadlocks is not None:
            pulumi.set(__self__, "innodb_print_all_deadlocks", innodb_print_all_deadlocks)
        if innodb_rollback_on_timeout is not None:
            pulumi.set(__self__, "innodb_rollback_on_timeout", innodb_rollback_on_timeout)
        if interactive_timeout is not None:
            pulumi.set(__self__, "interactive_timeout", interactive_timeout)
        if internal_tmp_mem_storage_engine is not None:
            pulumi.set(__self__, "internal_tmp_mem_storage_engine", internal_tmp_mem_storage_engine)
        if long_query_time is not None:
            pulumi.set(__self__, "long_query_time", long_query_time)
        if max_allowed_packet is not None:
            pulumi.set(__self__, "max_allowed_packet", max_allowed_packet)
        if max_heap_table_size is not None:
            pulumi.set(__self__, "max_heap_table_size", max_heap_table_size)
        if net_read_timeout is not None:
            pulumi.set(__self__, "net_read_timeout", net_read_timeout)
        if net_write_timeout is not None:
            pulumi.set(__self__, "net_write_timeout", net_write_timeout)
        if slow_query_log is not None:
            pulumi.set(__self__, "slow_query_log", slow_query_log)
        if sort_buffer_size is not None:
            pulumi.set(__self__, "sort_buffer_size", sort_buffer_size)
        if sql_mode is not None:
            pulumi.set(__self__, "sql_mode", sql_mode)
        if sql_require_primary_key is not None:
            pulumi.set(__self__, "sql_require_primary_key", sql_require_primary_key)
        if tmp_table_size is not None:
            pulumi.set(__self__, "tmp_table_size", tmp_table_size)
        if wait_timeout is not None:
            pulumi.set(__self__, "wait_timeout", wait_timeout)

    @_builtins.property
    @pulumi.getter(name="backupHour")
    def backup_hour(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The hour of day (in UTC) when backup for the service starts. New backup only starts if previous backup has already completed.
        """
        return pulumi.get(self, "backup_hour")

    @backup_hour.setter
    def backup_hour(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "backup_hour", value)

    @_builtins.property
    @pulumi.getter(name="backupMinute")
    def backup_minute(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minute of the backup hour when backup for the service starts. New backup only starts if previous backup has already completed.
        """
        return pulumi.get(self, "backup_minute")

    @backup_minute.setter
    def backup_minute(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "backup_minute", value)

    @_builtins.property
    @pulumi.getter(name="binlogRetentionPeriod")
    def binlog_retention_period(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum amount of time, in seconds, to keep binlog entries before deletion. This may be extended for services that require binlog entries for longer than the default, for example if using the MySQL Debezium Kafka connector.
        """
        return pulumi.get(self, "binlog_retention_period")

    @binlog_retention_period.setter
    def binlog_retention_period(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "binlog_retention_period", value)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the target MySQL cluster.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @_builtins.property
    @pulumi.getter(name="connectTimeout")
    def connect_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of seconds that the mysqld server waits for a connect packet before responding with bad handshake.
        """
        return pulumi.get(self, "connect_timeout")

    @connect_timeout.setter
    def connect_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "connect_timeout", value)

    @_builtins.property
    @pulumi.getter(name="defaultTimeZone")
    def default_time_zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Default server time zone, in the form of an offset from UTC (from -12:00 to +12:00), a time zone name (EST), or `SYSTEM` to use the MySQL server default.
        """
        return pulumi.get(self, "default_time_zone")

    @default_time_zone.setter
    def default_time_zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_time_zone", value)

    @_builtins.property
    @pulumi.getter(name="groupConcatMaxLen")
    def group_concat_max_len(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum permitted result length, in bytes, for the `GROUP_CONCAT()` function.
        """
        return pulumi.get(self, "group_concat_max_len")

    @group_concat_max_len.setter
    def group_concat_max_len(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "group_concat_max_len", value)

    @_builtins.property
    @pulumi.getter(name="informationSchemaStatsExpiry")
    def information_schema_stats_expiry(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The time, in seconds, before cached statistics expire.
        """
        return pulumi.get(self, "information_schema_stats_expiry")

    @information_schema_stats_expiry.setter
    def information_schema_stats_expiry(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "information_schema_stats_expiry", value)

    @_builtins.property
    @pulumi.getter(name="innodbFtMinTokenSize")
    def innodb_ft_min_token_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum length of words that an InnoDB FULLTEXT index stores.
        """
        return pulumi.get(self, "innodb_ft_min_token_size")

    @innodb_ft_min_token_size.setter
    def innodb_ft_min_token_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "innodb_ft_min_token_size", value)

    @_builtins.property
    @pulumi.getter(name="innodbFtServerStopwordTable")
    def innodb_ft_server_stopword_table(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The InnoDB FULLTEXT index stopword list for all InnoDB tables.
        """
        return pulumi.get(self, "innodb_ft_server_stopword_table")

    @innodb_ft_server_stopword_table.setter
    def innodb_ft_server_stopword_table(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "innodb_ft_server_stopword_table", value)

    @_builtins.property
    @pulumi.getter(name="innodbLockWaitTimeout")
    def innodb_lock_wait_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The time, in seconds, that an InnoDB transaction waits for a row lock. before giving up.
        """
        return pulumi.get(self, "innodb_lock_wait_timeout")

    @innodb_lock_wait_timeout.setter
    def innodb_lock_wait_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "innodb_lock_wait_timeout", value)

    @_builtins.property
    @pulumi.getter(name="innodbLogBufferSize")
    def innodb_log_buffer_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The size of the buffer, in bytes, that InnoDB uses to write to the log files. on disk.
        """
        return pulumi.get(self, "innodb_log_buffer_size")

    @innodb_log_buffer_size.setter
    def innodb_log_buffer_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "innodb_log_buffer_size", value)

    @_builtins.property
    @pulumi.getter(name="innodbOnlineAlterLogMaxSize")
    def innodb_online_alter_log_max_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The upper limit, in bytes, of the size of the temporary log files used during online DDL operations for InnoDB tables.
        """
        return pulumi.get(self, "innodb_online_alter_log_max_size")

    @innodb_online_alter_log_max_size.setter
    def innodb_online_alter_log_max_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "innodb_online_alter_log_max_size", value)

    @_builtins.property
    @pulumi.getter(name="innodbPrintAllDeadlocks")
    def innodb_print_all_deadlocks(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When enabled, records information about all deadlocks in InnoDB user transactions in the error log. Disabled by default.
        """
        return pulumi.get(self, "innodb_print_all_deadlocks")

    @innodb_print_all_deadlocks.setter
    def innodb_print_all_deadlocks(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "innodb_print_all_deadlocks", value)

    @_builtins.property
    @pulumi.getter(name="innodbRollbackOnTimeout")
    def innodb_rollback_on_timeout(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When enabled, transaction timeouts cause InnoDB to abort and roll back the entire transaction.
        """
        return pulumi.get(self, "innodb_rollback_on_timeout")

    @innodb_rollback_on_timeout.setter
    def innodb_rollback_on_timeout(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "innodb_rollback_on_timeout", value)

    @_builtins.property
    @pulumi.getter(name="interactiveTimeout")
    def interactive_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The time, in seconds, the server waits for activity on an interactive. connection before closing it.
        """
        return pulumi.get(self, "interactive_timeout")

    @interactive_timeout.setter
    def interactive_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "interactive_timeout", value)

    @_builtins.property
    @pulumi.getter(name="internalTmpMemStorageEngine")
    def internal_tmp_mem_storage_engine(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The storage engine for in-memory internal temporary tables. Supported values are: `TempTable`, `MEMORY`.
        """
        return pulumi.get(self, "internal_tmp_mem_storage_engine")

    @internal_tmp_mem_storage_engine.setter
    def internal_tmp_mem_storage_engine(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "internal_tmp_mem_storage_engine", value)

    @_builtins.property
    @pulumi.getter(name="longQueryTime")
    def long_query_time(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        The time, in seconds, for a query to take to execute before being captured by `slow_query_logs`. Default is `10` seconds.
        """
        return pulumi.get(self, "long_query_time")

    @long_query_time.setter
    def long_query_time(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "long_query_time", value)

    @_builtins.property
    @pulumi.getter(name="maxAllowedPacket")
    def max_allowed_packet(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The size of the largest message, in bytes, that can be received by the server. Default is `67108864` (64M).
        """
        return pulumi.get(self, "max_allowed_packet")

    @max_allowed_packet.setter
    def max_allowed_packet(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_allowed_packet", value)

    @_builtins.property
    @pulumi.getter(name="maxHeapTableSize")
    def max_heap_table_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum size, in bytes, of internal in-memory tables. Also set `tmp_table_size`. Default is `16777216` (16M)
        """
        return pulumi.get(self, "max_heap_table_size")

    @max_heap_table_size.setter
    def max_heap_table_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_heap_table_size", value)

    @_builtins.property
    @pulumi.getter(name="netReadTimeout")
    def net_read_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The time, in seconds, to wait for more data from an existing connection. aborting the read.
        """
        return pulumi.get(self, "net_read_timeout")

    @net_read_timeout.setter
    def net_read_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "net_read_timeout", value)

    @_builtins.property
    @pulumi.getter(name="netWriteTimeout")
    def net_write_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of seconds to wait for a block to be written to a connection before aborting the write.
        """
        return pulumi.get(self, "net_write_timeout")

    @net_write_timeout.setter
    def net_write_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "net_write_timeout", value)

    @_builtins.property
    @pulumi.getter(name="slowQueryLog")
    def slow_query_log(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        When enabled, captures slow queries. When disabled, also truncates the mysql.slow_log table. Default is false.
        """
        return pulumi.get(self, "slow_query_log")

    @slow_query_log.setter
    def slow_query_log(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "slow_query_log", value)

    @_builtins.property
    @pulumi.getter(name="sortBufferSize")
    def sort_buffer_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The sort buffer size, in bytes, for `ORDER BY` optimization. Default is `262144`. (256K).
        """
        return pulumi.get(self, "sort_buffer_size")

    @sort_buffer_size.setter
    def sort_buffer_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "sort_buffer_size", value)

    @_builtins.property
    @pulumi.getter(name="sqlMode")
    def sql_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Global SQL mode. If empty, uses MySQL server defaults. Must only include uppercase alphabetic characters, underscores, and commas.
        """
        return pulumi.get(self, "sql_mode")

    @sql_mode.setter
    def sql_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sql_mode", value)

    @_builtins.property
    @pulumi.getter(name="sqlRequirePrimaryKey")
    def sql_require_primary_key(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Require primary key to be defined for new tables or old tables modified with ALTER TABLE and fail if missing. It is recommended to always have primary keys because various functionality may break if any large table is missing them.
        """
        return pulumi.get(self, "sql_require_primary_key")

    @sql_require_primary_key.setter
    def sql_require_primary_key(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "sql_require_primary_key", value)

    @_builtins.property
    @pulumi.getter(name="tmpTableSize")
    def tmp_table_size(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum size, in bytes, of internal in-memory tables. Also set `max_heap_table_size`. Default is `16777216` (16M).
        """
        return pulumi.get(self, "tmp_table_size")

    @tmp_table_size.setter
    def tmp_table_size(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "tmp_table_size", value)

    @_builtins.property
    @pulumi.getter(name="waitTimeout")
    def wait_timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The number of seconds the server waits for activity on a noninteractive connection before closing it.
        """
        return pulumi.get(self, "wait_timeout")

    @wait_timeout.setter
    def wait_timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "wait_timeout", value)


@pulumi.type_token("digitalocean:index/databaseMysqlConfig:DatabaseMysqlConfig")
class DatabaseMysqlConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_hour: Optional[pulumi.Input[_builtins.int]] = None,
                 backup_minute: Optional[pulumi.Input[_builtins.int]] = None,
                 binlog_retention_period: Optional[pulumi.Input[_builtins.int]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 connect_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 default_time_zone: Optional[pulumi.Input[_builtins.str]] = None,
                 group_concat_max_len: Optional[pulumi.Input[_builtins.int]] = None,
                 information_schema_stats_expiry: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_ft_min_token_size: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_ft_server_stopword_table: Optional[pulumi.Input[_builtins.str]] = None,
                 innodb_lock_wait_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_log_buffer_size: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_online_alter_log_max_size: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_print_all_deadlocks: Optional[pulumi.Input[_builtins.bool]] = None,
                 innodb_rollback_on_timeout: Optional[pulumi.Input[_builtins.bool]] = None,
                 interactive_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 internal_tmp_mem_storage_engine: Optional[pulumi.Input[_builtins.str]] = None,
                 long_query_time: Optional[pulumi.Input[_builtins.float]] = None,
                 max_allowed_packet: Optional[pulumi.Input[_builtins.int]] = None,
                 max_heap_table_size: Optional[pulumi.Input[_builtins.int]] = None,
                 net_read_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 net_write_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 slow_query_log: Optional[pulumi.Input[_builtins.bool]] = None,
                 sort_buffer_size: Optional[pulumi.Input[_builtins.int]] = None,
                 sql_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 sql_require_primary_key: Optional[pulumi.Input[_builtins.bool]] = None,
                 tmp_table_size: Optional[pulumi.Input[_builtins.int]] = None,
                 wait_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Provides a virtual resource that can be used to change advanced configuration
        options for a DigitalOcean managed MySQL database cluster.

        > **Note** MySQL configurations are only removed from state when destroyed. The remote configuration is not unset.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        example_database_cluster = digitalocean.DatabaseCluster("example",
            name="example-mysql-cluster",
            engine="mysql",
            version="8",
            size=digitalocean.DatabaseSlug.D_B_1_VPCU1_GB,
            region=digitalocean.Region.NYC1,
            node_count=1)
        example = digitalocean.DatabaseMysqlConfig("example",
            cluster_id=example_database_cluster.id,
            connect_timeout=10,
            default_time_zone="UTC")
        ```

        ## Import

        A MySQL database cluster's configuration can be imported using the `id` the parent cluster, e.g.

        ```sh
        $ pulumi import digitalocean:index/databaseMysqlConfig:DatabaseMysqlConfig example 4b62829a-9c42-465b-aaa3-84051048e712
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] backup_hour: The hour of day (in UTC) when backup for the service starts. New backup only starts if previous backup has already completed.
        :param pulumi.Input[_builtins.int] backup_minute: The minute of the backup hour when backup for the service starts. New backup only starts if previous backup has already completed.
        :param pulumi.Input[_builtins.int] binlog_retention_period: The minimum amount of time, in seconds, to keep binlog entries before deletion. This may be extended for services that require binlog entries for longer than the default, for example if using the MySQL Debezium Kafka connector.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the target MySQL cluster.
        :param pulumi.Input[_builtins.int] connect_timeout: The number of seconds that the mysqld server waits for a connect packet before responding with bad handshake.
        :param pulumi.Input[_builtins.str] default_time_zone: Default server time zone, in the form of an offset from UTC (from -12:00 to +12:00), a time zone name (EST), or `SYSTEM` to use the MySQL server default.
        :param pulumi.Input[_builtins.int] group_concat_max_len: The maximum permitted result length, in bytes, for the `GROUP_CONCAT()` function.
        :param pulumi.Input[_builtins.int] information_schema_stats_expiry: The time, in seconds, before cached statistics expire.
        :param pulumi.Input[_builtins.int] innodb_ft_min_token_size: The minimum length of words that an InnoDB FULLTEXT index stores.
        :param pulumi.Input[_builtins.str] innodb_ft_server_stopword_table: The InnoDB FULLTEXT index stopword list for all InnoDB tables.
        :param pulumi.Input[_builtins.int] innodb_lock_wait_timeout: The time, in seconds, that an InnoDB transaction waits for a row lock. before giving up.
        :param pulumi.Input[_builtins.int] innodb_log_buffer_size: The size of the buffer, in bytes, that InnoDB uses to write to the log files. on disk.
        :param pulumi.Input[_builtins.int] innodb_online_alter_log_max_size: The upper limit, in bytes, of the size of the temporary log files used during online DDL operations for InnoDB tables.
        :param pulumi.Input[_builtins.bool] innodb_print_all_deadlocks: When enabled, records information about all deadlocks in InnoDB user transactions in the error log. Disabled by default.
        :param pulumi.Input[_builtins.bool] innodb_rollback_on_timeout: When enabled, transaction timeouts cause InnoDB to abort and roll back the entire transaction.
        :param pulumi.Input[_builtins.int] interactive_timeout: The time, in seconds, the server waits for activity on an interactive. connection before closing it.
        :param pulumi.Input[_builtins.str] internal_tmp_mem_storage_engine: The storage engine for in-memory internal temporary tables. Supported values are: `TempTable`, `MEMORY`.
        :param pulumi.Input[_builtins.float] long_query_time: The time, in seconds, for a query to take to execute before being captured by `slow_query_logs`. Default is `10` seconds.
        :param pulumi.Input[_builtins.int] max_allowed_packet: The size of the largest message, in bytes, that can be received by the server. Default is `67108864` (64M).
        :param pulumi.Input[_builtins.int] max_heap_table_size: The maximum size, in bytes, of internal in-memory tables. Also set `tmp_table_size`. Default is `16777216` (16M)
        :param pulumi.Input[_builtins.int] net_read_timeout: The time, in seconds, to wait for more data from an existing connection. aborting the read.
        :param pulumi.Input[_builtins.int] net_write_timeout: The number of seconds to wait for a block to be written to a connection before aborting the write.
        :param pulumi.Input[_builtins.bool] slow_query_log: When enabled, captures slow queries. When disabled, also truncates the mysql.slow_log table. Default is false.
        :param pulumi.Input[_builtins.int] sort_buffer_size: The sort buffer size, in bytes, for `ORDER BY` optimization. Default is `262144`. (256K).
        :param pulumi.Input[_builtins.str] sql_mode: Global SQL mode. If empty, uses MySQL server defaults. Must only include uppercase alphabetic characters, underscores, and commas.
        :param pulumi.Input[_builtins.bool] sql_require_primary_key: Require primary key to be defined for new tables or old tables modified with ALTER TABLE and fail if missing. It is recommended to always have primary keys because various functionality may break if any large table is missing them.
        :param pulumi.Input[_builtins.int] tmp_table_size: The maximum size, in bytes, of internal in-memory tables. Also set `max_heap_table_size`. Default is `16777216` (16M).
        :param pulumi.Input[_builtins.int] wait_timeout: The number of seconds the server waits for activity on a noninteractive connection before closing it.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DatabaseMysqlConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a virtual resource that can be used to change advanced configuration
        options for a DigitalOcean managed MySQL database cluster.

        > **Note** MySQL configurations are only removed from state when destroyed. The remote configuration is not unset.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_digitalocean as digitalocean

        example_database_cluster = digitalocean.DatabaseCluster("example",
            name="example-mysql-cluster",
            engine="mysql",
            version="8",
            size=digitalocean.DatabaseSlug.D_B_1_VPCU1_GB,
            region=digitalocean.Region.NYC1,
            node_count=1)
        example = digitalocean.DatabaseMysqlConfig("example",
            cluster_id=example_database_cluster.id,
            connect_timeout=10,
            default_time_zone="UTC")
        ```

        ## Import

        A MySQL database cluster's configuration can be imported using the `id` the parent cluster, e.g.

        ```sh
        $ pulumi import digitalocean:index/databaseMysqlConfig:DatabaseMysqlConfig example 4b62829a-9c42-465b-aaa3-84051048e712
        ```

        :param str resource_name: The name of the resource.
        :param DatabaseMysqlConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DatabaseMysqlConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backup_hour: Optional[pulumi.Input[_builtins.int]] = None,
                 backup_minute: Optional[pulumi.Input[_builtins.int]] = None,
                 binlog_retention_period: Optional[pulumi.Input[_builtins.int]] = None,
                 cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                 connect_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 default_time_zone: Optional[pulumi.Input[_builtins.str]] = None,
                 group_concat_max_len: Optional[pulumi.Input[_builtins.int]] = None,
                 information_schema_stats_expiry: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_ft_min_token_size: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_ft_server_stopword_table: Optional[pulumi.Input[_builtins.str]] = None,
                 innodb_lock_wait_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_log_buffer_size: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_online_alter_log_max_size: Optional[pulumi.Input[_builtins.int]] = None,
                 innodb_print_all_deadlocks: Optional[pulumi.Input[_builtins.bool]] = None,
                 innodb_rollback_on_timeout: Optional[pulumi.Input[_builtins.bool]] = None,
                 interactive_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 internal_tmp_mem_storage_engine: Optional[pulumi.Input[_builtins.str]] = None,
                 long_query_time: Optional[pulumi.Input[_builtins.float]] = None,
                 max_allowed_packet: Optional[pulumi.Input[_builtins.int]] = None,
                 max_heap_table_size: Optional[pulumi.Input[_builtins.int]] = None,
                 net_read_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 net_write_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 slow_query_log: Optional[pulumi.Input[_builtins.bool]] = None,
                 sort_buffer_size: Optional[pulumi.Input[_builtins.int]] = None,
                 sql_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 sql_require_primary_key: Optional[pulumi.Input[_builtins.bool]] = None,
                 tmp_table_size: Optional[pulumi.Input[_builtins.int]] = None,
                 wait_timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DatabaseMysqlConfigArgs.__new__(DatabaseMysqlConfigArgs)

            __props__.__dict__["backup_hour"] = backup_hour
            __props__.__dict__["backup_minute"] = backup_minute
            __props__.__dict__["binlog_retention_period"] = binlog_retention_period
            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["connect_timeout"] = connect_timeout
            __props__.__dict__["default_time_zone"] = default_time_zone
            __props__.__dict__["group_concat_max_len"] = group_concat_max_len
            __props__.__dict__["information_schema_stats_expiry"] = information_schema_stats_expiry
            __props__.__dict__["innodb_ft_min_token_size"] = innodb_ft_min_token_size
            __props__.__dict__["innodb_ft_server_stopword_table"] = innodb_ft_server_stopword_table
            __props__.__dict__["innodb_lock_wait_timeout"] = innodb_lock_wait_timeout
            __props__.__dict__["innodb_log_buffer_size"] = innodb_log_buffer_size
            __props__.__dict__["innodb_online_alter_log_max_size"] = innodb_online_alter_log_max_size
            __props__.__dict__["innodb_print_all_deadlocks"] = innodb_print_all_deadlocks
            __props__.__dict__["innodb_rollback_on_timeout"] = innodb_rollback_on_timeout
            __props__.__dict__["interactive_timeout"] = interactive_timeout
            __props__.__dict__["internal_tmp_mem_storage_engine"] = internal_tmp_mem_storage_engine
            __props__.__dict__["long_query_time"] = long_query_time
            __props__.__dict__["max_allowed_packet"] = max_allowed_packet
            __props__.__dict__["max_heap_table_size"] = max_heap_table_size
            __props__.__dict__["net_read_timeout"] = net_read_timeout
            __props__.__dict__["net_write_timeout"] = net_write_timeout
            __props__.__dict__["slow_query_log"] = slow_query_log
            __props__.__dict__["sort_buffer_size"] = sort_buffer_size
            __props__.__dict__["sql_mode"] = sql_mode
            __props__.__dict__["sql_require_primary_key"] = sql_require_primary_key
            __props__.__dict__["tmp_table_size"] = tmp_table_size
            __props__.__dict__["wait_timeout"] = wait_timeout
        super(DatabaseMysqlConfig, __self__).__init__(
            'digitalocean:index/databaseMysqlConfig:DatabaseMysqlConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backup_hour: Optional[pulumi.Input[_builtins.int]] = None,
            backup_minute: Optional[pulumi.Input[_builtins.int]] = None,
            binlog_retention_period: Optional[pulumi.Input[_builtins.int]] = None,
            cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
            connect_timeout: Optional[pulumi.Input[_builtins.int]] = None,
            default_time_zone: Optional[pulumi.Input[_builtins.str]] = None,
            group_concat_max_len: Optional[pulumi.Input[_builtins.int]] = None,
            information_schema_stats_expiry: Optional[pulumi.Input[_builtins.int]] = None,
            innodb_ft_min_token_size: Optional[pulumi.Input[_builtins.int]] = None,
            innodb_ft_server_stopword_table: Optional[pulumi.Input[_builtins.str]] = None,
            innodb_lock_wait_timeout: Optional[pulumi.Input[_builtins.int]] = None,
            innodb_log_buffer_size: Optional[pulumi.Input[_builtins.int]] = None,
            innodb_online_alter_log_max_size: Optional[pulumi.Input[_builtins.int]] = None,
            innodb_print_all_deadlocks: Optional[pulumi.Input[_builtins.bool]] = None,
            innodb_rollback_on_timeout: Optional[pulumi.Input[_builtins.bool]] = None,
            interactive_timeout: Optional[pulumi.Input[_builtins.int]] = None,
            internal_tmp_mem_storage_engine: Optional[pulumi.Input[_builtins.str]] = None,
            long_query_time: Optional[pulumi.Input[_builtins.float]] = None,
            max_allowed_packet: Optional[pulumi.Input[_builtins.int]] = None,
            max_heap_table_size: Optional[pulumi.Input[_builtins.int]] = None,
            net_read_timeout: Optional[pulumi.Input[_builtins.int]] = None,
            net_write_timeout: Optional[pulumi.Input[_builtins.int]] = None,
            slow_query_log: Optional[pulumi.Input[_builtins.bool]] = None,
            sort_buffer_size: Optional[pulumi.Input[_builtins.int]] = None,
            sql_mode: Optional[pulumi.Input[_builtins.str]] = None,
            sql_require_primary_key: Optional[pulumi.Input[_builtins.bool]] = None,
            tmp_table_size: Optional[pulumi.Input[_builtins.int]] = None,
            wait_timeout: Optional[pulumi.Input[_builtins.int]] = None) -> 'DatabaseMysqlConfig':
        """
        Get an existing DatabaseMysqlConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.int] backup_hour: The hour of day (in UTC) when backup for the service starts. New backup only starts if previous backup has already completed.
        :param pulumi.Input[_builtins.int] backup_minute: The minute of the backup hour when backup for the service starts. New backup only starts if previous backup has already completed.
        :param pulumi.Input[_builtins.int] binlog_retention_period: The minimum amount of time, in seconds, to keep binlog entries before deletion. This may be extended for services that require binlog entries for longer than the default, for example if using the MySQL Debezium Kafka connector.
        :param pulumi.Input[_builtins.str] cluster_id: The ID of the target MySQL cluster.
        :param pulumi.Input[_builtins.int] connect_timeout: The number of seconds that the mysqld server waits for a connect packet before responding with bad handshake.
        :param pulumi.Input[_builtins.str] default_time_zone: Default server time zone, in the form of an offset from UTC (from -12:00 to +12:00), a time zone name (EST), or `SYSTEM` to use the MySQL server default.
        :param pulumi.Input[_builtins.int] group_concat_max_len: The maximum permitted result length, in bytes, for the `GROUP_CONCAT()` function.
        :param pulumi.Input[_builtins.int] information_schema_stats_expiry: The time, in seconds, before cached statistics expire.
        :param pulumi.Input[_builtins.int] innodb_ft_min_token_size: The minimum length of words that an InnoDB FULLTEXT index stores.
        :param pulumi.Input[_builtins.str] innodb_ft_server_stopword_table: The InnoDB FULLTEXT index stopword list for all InnoDB tables.
        :param pulumi.Input[_builtins.int] innodb_lock_wait_timeout: The time, in seconds, that an InnoDB transaction waits for a row lock. before giving up.
        :param pulumi.Input[_builtins.int] innodb_log_buffer_size: The size of the buffer, in bytes, that InnoDB uses to write to the log files. on disk.
        :param pulumi.Input[_builtins.int] innodb_online_alter_log_max_size: The upper limit, in bytes, of the size of the temporary log files used during online DDL operations for InnoDB tables.
        :param pulumi.Input[_builtins.bool] innodb_print_all_deadlocks: When enabled, records information about all deadlocks in InnoDB user transactions in the error log. Disabled by default.
        :param pulumi.Input[_builtins.bool] innodb_rollback_on_timeout: When enabled, transaction timeouts cause InnoDB to abort and roll back the entire transaction.
        :param pulumi.Input[_builtins.int] interactive_timeout: The time, in seconds, the server waits for activity on an interactive. connection before closing it.
        :param pulumi.Input[_builtins.str] internal_tmp_mem_storage_engine: The storage engine for in-memory internal temporary tables. Supported values are: `TempTable`, `MEMORY`.
        :param pulumi.Input[_builtins.float] long_query_time: The time, in seconds, for a query to take to execute before being captured by `slow_query_logs`. Default is `10` seconds.
        :param pulumi.Input[_builtins.int] max_allowed_packet: The size of the largest message, in bytes, that can be received by the server. Default is `67108864` (64M).
        :param pulumi.Input[_builtins.int] max_heap_table_size: The maximum size, in bytes, of internal in-memory tables. Also set `tmp_table_size`. Default is `16777216` (16M)
        :param pulumi.Input[_builtins.int] net_read_timeout: The time, in seconds, to wait for more data from an existing connection. aborting the read.
        :param pulumi.Input[_builtins.int] net_write_timeout: The number of seconds to wait for a block to be written to a connection before aborting the write.
        :param pulumi.Input[_builtins.bool] slow_query_log: When enabled, captures slow queries. When disabled, also truncates the mysql.slow_log table. Default is false.
        :param pulumi.Input[_builtins.int] sort_buffer_size: The sort buffer size, in bytes, for `ORDER BY` optimization. Default is `262144`. (256K).
        :param pulumi.Input[_builtins.str] sql_mode: Global SQL mode. If empty, uses MySQL server defaults. Must only include uppercase alphabetic characters, underscores, and commas.
        :param pulumi.Input[_builtins.bool] sql_require_primary_key: Require primary key to be defined for new tables or old tables modified with ALTER TABLE and fail if missing. It is recommended to always have primary keys because various functionality may break if any large table is missing them.
        :param pulumi.Input[_builtins.int] tmp_table_size: The maximum size, in bytes, of internal in-memory tables. Also set `max_heap_table_size`. Default is `16777216` (16M).
        :param pulumi.Input[_builtins.int] wait_timeout: The number of seconds the server waits for activity on a noninteractive connection before closing it.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DatabaseMysqlConfigState.__new__(_DatabaseMysqlConfigState)

        __props__.__dict__["backup_hour"] = backup_hour
        __props__.__dict__["backup_minute"] = backup_minute
        __props__.__dict__["binlog_retention_period"] = binlog_retention_period
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["connect_timeout"] = connect_timeout
        __props__.__dict__["default_time_zone"] = default_time_zone
        __props__.__dict__["group_concat_max_len"] = group_concat_max_len
        __props__.__dict__["information_schema_stats_expiry"] = information_schema_stats_expiry
        __props__.__dict__["innodb_ft_min_token_size"] = innodb_ft_min_token_size
        __props__.__dict__["innodb_ft_server_stopword_table"] = innodb_ft_server_stopword_table
        __props__.__dict__["innodb_lock_wait_timeout"] = innodb_lock_wait_timeout
        __props__.__dict__["innodb_log_buffer_size"] = innodb_log_buffer_size
        __props__.__dict__["innodb_online_alter_log_max_size"] = innodb_online_alter_log_max_size
        __props__.__dict__["innodb_print_all_deadlocks"] = innodb_print_all_deadlocks
        __props__.__dict__["innodb_rollback_on_timeout"] = innodb_rollback_on_timeout
        __props__.__dict__["interactive_timeout"] = interactive_timeout
        __props__.__dict__["internal_tmp_mem_storage_engine"] = internal_tmp_mem_storage_engine
        __props__.__dict__["long_query_time"] = long_query_time
        __props__.__dict__["max_allowed_packet"] = max_allowed_packet
        __props__.__dict__["max_heap_table_size"] = max_heap_table_size
        __props__.__dict__["net_read_timeout"] = net_read_timeout
        __props__.__dict__["net_write_timeout"] = net_write_timeout
        __props__.__dict__["slow_query_log"] = slow_query_log
        __props__.__dict__["sort_buffer_size"] = sort_buffer_size
        __props__.__dict__["sql_mode"] = sql_mode
        __props__.__dict__["sql_require_primary_key"] = sql_require_primary_key
        __props__.__dict__["tmp_table_size"] = tmp_table_size
        __props__.__dict__["wait_timeout"] = wait_timeout
        return DatabaseMysqlConfig(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="backupHour")
    def backup_hour(self) -> pulumi.Output[_builtins.int]:
        """
        The hour of day (in UTC) when backup for the service starts. New backup only starts if previous backup has already completed.
        """
        return pulumi.get(self, "backup_hour")

    @_builtins.property
    @pulumi.getter(name="backupMinute")
    def backup_minute(self) -> pulumi.Output[_builtins.int]:
        """
        The minute of the backup hour when backup for the service starts. New backup only starts if previous backup has already completed.
        """
        return pulumi.get(self, "backup_minute")

    @_builtins.property
    @pulumi.getter(name="binlogRetentionPeriod")
    def binlog_retention_period(self) -> pulumi.Output[_builtins.int]:
        """
        The minimum amount of time, in seconds, to keep binlog entries before deletion. This may be extended for services that require binlog entries for longer than the default, for example if using the MySQL Debezium Kafka connector.
        """
        return pulumi.get(self, "binlog_retention_period")

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the target MySQL cluster.
        """
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter(name="connectTimeout")
    def connect_timeout(self) -> pulumi.Output[_builtins.int]:
        """
        The number of seconds that the mysqld server waits for a connect packet before responding with bad handshake.
        """
        return pulumi.get(self, "connect_timeout")

    @_builtins.property
    @pulumi.getter(name="defaultTimeZone")
    def default_time_zone(self) -> pulumi.Output[_builtins.str]:
        """
        Default server time zone, in the form of an offset from UTC (from -12:00 to +12:00), a time zone name (EST), or `SYSTEM` to use the MySQL server default.
        """
        return pulumi.get(self, "default_time_zone")

    @_builtins.property
    @pulumi.getter(name="groupConcatMaxLen")
    def group_concat_max_len(self) -> pulumi.Output[_builtins.int]:
        """
        The maximum permitted result length, in bytes, for the `GROUP_CONCAT()` function.
        """
        return pulumi.get(self, "group_concat_max_len")

    @_builtins.property
    @pulumi.getter(name="informationSchemaStatsExpiry")
    def information_schema_stats_expiry(self) -> pulumi.Output[_builtins.int]:
        """
        The time, in seconds, before cached statistics expire.
        """
        return pulumi.get(self, "information_schema_stats_expiry")

    @_builtins.property
    @pulumi.getter(name="innodbFtMinTokenSize")
    def innodb_ft_min_token_size(self) -> pulumi.Output[_builtins.int]:
        """
        The minimum length of words that an InnoDB FULLTEXT index stores.
        """
        return pulumi.get(self, "innodb_ft_min_token_size")

    @_builtins.property
    @pulumi.getter(name="innodbFtServerStopwordTable")
    def innodb_ft_server_stopword_table(self) -> pulumi.Output[_builtins.str]:
        """
        The InnoDB FULLTEXT index stopword list for all InnoDB tables.
        """
        return pulumi.get(self, "innodb_ft_server_stopword_table")

    @_builtins.property
    @pulumi.getter(name="innodbLockWaitTimeout")
    def innodb_lock_wait_timeout(self) -> pulumi.Output[_builtins.int]:
        """
        The time, in seconds, that an InnoDB transaction waits for a row lock. before giving up.
        """
        return pulumi.get(self, "innodb_lock_wait_timeout")

    @_builtins.property
    @pulumi.getter(name="innodbLogBufferSize")
    def innodb_log_buffer_size(self) -> pulumi.Output[_builtins.int]:
        """
        The size of the buffer, in bytes, that InnoDB uses to write to the log files. on disk.
        """
        return pulumi.get(self, "innodb_log_buffer_size")

    @_builtins.property
    @pulumi.getter(name="innodbOnlineAlterLogMaxSize")
    def innodb_online_alter_log_max_size(self) -> pulumi.Output[_builtins.int]:
        """
        The upper limit, in bytes, of the size of the temporary log files used during online DDL operations for InnoDB tables.
        """
        return pulumi.get(self, "innodb_online_alter_log_max_size")

    @_builtins.property
    @pulumi.getter(name="innodbPrintAllDeadlocks")
    def innodb_print_all_deadlocks(self) -> pulumi.Output[_builtins.bool]:
        """
        When enabled, records information about all deadlocks in InnoDB user transactions in the error log. Disabled by default.
        """
        return pulumi.get(self, "innodb_print_all_deadlocks")

    @_builtins.property
    @pulumi.getter(name="innodbRollbackOnTimeout")
    def innodb_rollback_on_timeout(self) -> pulumi.Output[_builtins.bool]:
        """
        When enabled, transaction timeouts cause InnoDB to abort and roll back the entire transaction.
        """
        return pulumi.get(self, "innodb_rollback_on_timeout")

    @_builtins.property
    @pulumi.getter(name="interactiveTimeout")
    def interactive_timeout(self) -> pulumi.Output[_builtins.int]:
        """
        The time, in seconds, the server waits for activity on an interactive. connection before closing it.
        """
        return pulumi.get(self, "interactive_timeout")

    @_builtins.property
    @pulumi.getter(name="internalTmpMemStorageEngine")
    def internal_tmp_mem_storage_engine(self) -> pulumi.Output[_builtins.str]:
        """
        The storage engine for in-memory internal temporary tables. Supported values are: `TempTable`, `MEMORY`.
        """
        return pulumi.get(self, "internal_tmp_mem_storage_engine")

    @_builtins.property
    @pulumi.getter(name="longQueryTime")
    def long_query_time(self) -> pulumi.Output[_builtins.float]:
        """
        The time, in seconds, for a query to take to execute before being captured by `slow_query_logs`. Default is `10` seconds.
        """
        return pulumi.get(self, "long_query_time")

    @_builtins.property
    @pulumi.getter(name="maxAllowedPacket")
    def max_allowed_packet(self) -> pulumi.Output[_builtins.int]:
        """
        The size of the largest message, in bytes, that can be received by the server. Default is `67108864` (64M).
        """
        return pulumi.get(self, "max_allowed_packet")

    @_builtins.property
    @pulumi.getter(name="maxHeapTableSize")
    def max_heap_table_size(self) -> pulumi.Output[_builtins.int]:
        """
        The maximum size, in bytes, of internal in-memory tables. Also set `tmp_table_size`. Default is `16777216` (16M)
        """
        return pulumi.get(self, "max_heap_table_size")

    @_builtins.property
    @pulumi.getter(name="netReadTimeout")
    def net_read_timeout(self) -> pulumi.Output[_builtins.int]:
        """
        The time, in seconds, to wait for more data from an existing connection. aborting the read.
        """
        return pulumi.get(self, "net_read_timeout")

    @_builtins.property
    @pulumi.getter(name="netWriteTimeout")
    def net_write_timeout(self) -> pulumi.Output[_builtins.int]:
        """
        The number of seconds to wait for a block to be written to a connection before aborting the write.
        """
        return pulumi.get(self, "net_write_timeout")

    @_builtins.property
    @pulumi.getter(name="slowQueryLog")
    def slow_query_log(self) -> pulumi.Output[_builtins.bool]:
        """
        When enabled, captures slow queries. When disabled, also truncates the mysql.slow_log table. Default is false.
        """
        return pulumi.get(self, "slow_query_log")

    @_builtins.property
    @pulumi.getter(name="sortBufferSize")
    def sort_buffer_size(self) -> pulumi.Output[_builtins.int]:
        """
        The sort buffer size, in bytes, for `ORDER BY` optimization. Default is `262144`. (256K).
        """
        return pulumi.get(self, "sort_buffer_size")

    @_builtins.property
    @pulumi.getter(name="sqlMode")
    def sql_mode(self) -> pulumi.Output[_builtins.str]:
        """
        Global SQL mode. If empty, uses MySQL server defaults. Must only include uppercase alphabetic characters, underscores, and commas.
        """
        return pulumi.get(self, "sql_mode")

    @_builtins.property
    @pulumi.getter(name="sqlRequirePrimaryKey")
    def sql_require_primary_key(self) -> pulumi.Output[_builtins.bool]:
        """
        Require primary key to be defined for new tables or old tables modified with ALTER TABLE and fail if missing. It is recommended to always have primary keys because various functionality may break if any large table is missing them.
        """
        return pulumi.get(self, "sql_require_primary_key")

    @_builtins.property
    @pulumi.getter(name="tmpTableSize")
    def tmp_table_size(self) -> pulumi.Output[_builtins.int]:
        """
        The maximum size, in bytes, of internal in-memory tables. Also set `max_heap_table_size`. Default is `16777216` (16M).
        """
        return pulumi.get(self, "tmp_table_size")

    @_builtins.property
    @pulumi.getter(name="waitTimeout")
    def wait_timeout(self) -> pulumi.Output[_builtins.int]:
        """
        The number of seconds the server waits for activity on a noninteractive connection before closing it.
        """
        return pulumi.get(self, "wait_timeout")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetDropletResult',
    'AwaitableGetDropletResult',
    'get_droplet',
    'get_droplet_output',
]

@pulumi.output_type
class GetDropletResult:
    """
    A collection of values returned by getDroplet.
    """
    def __init__(__self__, backups=None, created_at=None, disk=None, gpu=None, id=None, image=None, ipv4_address=None, ipv4_address_private=None, ipv6=None, ipv6_address=None, ipv6_address_private=None, locked=None, memory=None, monitoring=None, name=None, price_hourly=None, price_monthly=None, private_networking=None, region=None, size=None, status=None, tag=None, tags=None, urn=None, vcpus=None, volume_ids=None, vpc_uuid=None):
        if backups and not isinstance(backups, bool):
            raise TypeError("Expected argument 'backups' to be a bool")
        pulumi.set(__self__, "backups", backups)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if disk and not isinstance(disk, int):
            raise TypeError("Expected argument 'disk' to be a int")
        pulumi.set(__self__, "disk", disk)
        if gpu and not isinstance(gpu, bool):
            raise TypeError("Expected argument 'gpu' to be a bool")
        pulumi.set(__self__, "gpu", gpu)
        if id and not isinstance(id, int):
            raise TypeError("Expected argument 'id' to be a int")
        pulumi.set(__self__, "id", id)
        if image and not isinstance(image, str):
            raise TypeError("Expected argument 'image' to be a str")
        pulumi.set(__self__, "image", image)
        if ipv4_address and not isinstance(ipv4_address, str):
            raise TypeError("Expected argument 'ipv4_address' to be a str")
        pulumi.set(__self__, "ipv4_address", ipv4_address)
        if ipv4_address_private and not isinstance(ipv4_address_private, str):
            raise TypeError("Expected argument 'ipv4_address_private' to be a str")
        pulumi.set(__self__, "ipv4_address_private", ipv4_address_private)
        if ipv6 and not isinstance(ipv6, bool):
            raise TypeError("Expected argument 'ipv6' to be a bool")
        pulumi.set(__self__, "ipv6", ipv6)
        if ipv6_address and not isinstance(ipv6_address, str):
            raise TypeError("Expected argument 'ipv6_address' to be a str")
        pulumi.set(__self__, "ipv6_address", ipv6_address)
        if ipv6_address_private and not isinstance(ipv6_address_private, str):
            raise TypeError("Expected argument 'ipv6_address_private' to be a str")
        pulumi.set(__self__, "ipv6_address_private", ipv6_address_private)
        if locked and not isinstance(locked, bool):
            raise TypeError("Expected argument 'locked' to be a bool")
        pulumi.set(__self__, "locked", locked)
        if memory and not isinstance(memory, int):
            raise TypeError("Expected argument 'memory' to be a int")
        pulumi.set(__self__, "memory", memory)
        if monitoring and not isinstance(monitoring, bool):
            raise TypeError("Expected argument 'monitoring' to be a bool")
        pulumi.set(__self__, "monitoring", monitoring)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if price_hourly and not isinstance(price_hourly, float):
            raise TypeError("Expected argument 'price_hourly' to be a float")
        pulumi.set(__self__, "price_hourly", price_hourly)
        if price_monthly and not isinstance(price_monthly, float):
            raise TypeError("Expected argument 'price_monthly' to be a float")
        pulumi.set(__self__, "price_monthly", price_monthly)
        if private_networking and not isinstance(private_networking, bool):
            raise TypeError("Expected argument 'private_networking' to be a bool")
        pulumi.set(__self__, "private_networking", private_networking)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if size and not isinstance(size, str):
            raise TypeError("Expected argument 'size' to be a str")
        pulumi.set(__self__, "size", size)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tag and not isinstance(tag, str):
            raise TypeError("Expected argument 'tag' to be a str")
        pulumi.set(__self__, "tag", tag)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if urn and not isinstance(urn, str):
            raise TypeError("Expected argument 'urn' to be a str")
        pulumi.set(__self__, "urn", urn)
        if vcpus and not isinstance(vcpus, int):
            raise TypeError("Expected argument 'vcpus' to be a int")
        pulumi.set(__self__, "vcpus", vcpus)
        if volume_ids and not isinstance(volume_ids, list):
            raise TypeError("Expected argument 'volume_ids' to be a list")
        pulumi.set(__self__, "volume_ids", volume_ids)
        if vpc_uuid and not isinstance(vpc_uuid, str):
            raise TypeError("Expected argument 'vpc_uuid' to be a str")
        pulumi.set(__self__, "vpc_uuid", vpc_uuid)

    @_builtins.property
    @pulumi.getter
    def backups(self) -> _builtins.bool:
        """
        Whether backups are enabled.
        """
        return pulumi.get(self, "backups")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def disk(self) -> _builtins.int:
        """
        The size of the Droplets disk in GB.
        """
        return pulumi.get(self, "disk")

    @_builtins.property
    @pulumi.getter
    def gpu(self) -> Optional[_builtins.bool]:
        return pulumi.get(self, "gpu")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.int:
        """
        The ID of the Droplet.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def image(self) -> _builtins.str:
        """
        The Droplet image ID or slug.
        """
        return pulumi.get(self, "image")

    @_builtins.property
    @pulumi.getter(name="ipv4Address")
    def ipv4_address(self) -> _builtins.str:
        """
        The Droplets public IPv4 address
        """
        return pulumi.get(self, "ipv4_address")

    @_builtins.property
    @pulumi.getter(name="ipv4AddressPrivate")
    def ipv4_address_private(self) -> _builtins.str:
        """
        The Droplets private IPv4 address
        """
        return pulumi.get(self, "ipv4_address_private")

    @_builtins.property
    @pulumi.getter
    def ipv6(self) -> _builtins.bool:
        """
        Whether IPv6 is enabled.
        """
        return pulumi.get(self, "ipv6")

    @_builtins.property
    @pulumi.getter(name="ipv6Address")
    def ipv6_address(self) -> _builtins.str:
        """
        The Droplets public IPv6 address
        """
        return pulumi.get(self, "ipv6_address")

    @_builtins.property
    @pulumi.getter(name="ipv6AddressPrivate")
    def ipv6_address_private(self) -> _builtins.str:
        """
        The Droplets private IPv6 address
        """
        return pulumi.get(self, "ipv6_address_private")

    @_builtins.property
    @pulumi.getter
    def locked(self) -> _builtins.bool:
        """
        Whether the Droplet is locked.
        """
        return pulumi.get(self, "locked")

    @_builtins.property
    @pulumi.getter
    def memory(self) -> _builtins.int:
        """
        The amount of the Droplets memory in MB.
        """
        return pulumi.get(self, "memory")

    @_builtins.property
    @pulumi.getter
    def monitoring(self) -> _builtins.bool:
        """
        Whether monitoring agent is installed.
        """
        return pulumi.get(self, "monitoring")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="priceHourly")
    def price_hourly(self) -> _builtins.float:
        """
        Droplet hourly price.
        """
        return pulumi.get(self, "price_hourly")

    @_builtins.property
    @pulumi.getter(name="priceMonthly")
    def price_monthly(self) -> _builtins.float:
        """
        Droplet monthly price.
        """
        return pulumi.get(self, "price_monthly")

    @_builtins.property
    @pulumi.getter(name="privateNetworking")
    def private_networking(self) -> _builtins.bool:
        """
        Whether private networks are enabled.
        """
        return pulumi.get(self, "private_networking")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The region the Droplet is running in.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def size(self) -> _builtins.str:
        """
        The unique slug that identifies the type of Droplet.
        """
        return pulumi.get(self, "size")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The status of the Droplet.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tag(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "tag")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        A list of the tags associated to the Droplet.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def urn(self) -> _builtins.str:
        """
        The uniform resource name of the Droplet
        """
        return pulumi.get(self, "urn")

    @_builtins.property
    @pulumi.getter
    def vcpus(self) -> _builtins.int:
        """
        The number of the Droplets virtual CPUs.
        """
        return pulumi.get(self, "vcpus")

    @_builtins.property
    @pulumi.getter(name="volumeIds")
    def volume_ids(self) -> Sequence[_builtins.str]:
        """
        List of the IDs of each volumes attached to the Droplet.
        """
        return pulumi.get(self, "volume_ids")

    @_builtins.property
    @pulumi.getter(name="vpcUuid")
    def vpc_uuid(self) -> _builtins.str:
        """
        The ID of the VPC where the Droplet is located.
        """
        return pulumi.get(self, "vpc_uuid")


class AwaitableGetDropletResult(GetDropletResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDropletResult(
            backups=self.backups,
            created_at=self.created_at,
            disk=self.disk,
            gpu=self.gpu,
            id=self.id,
            image=self.image,
            ipv4_address=self.ipv4_address,
            ipv4_address_private=self.ipv4_address_private,
            ipv6=self.ipv6,
            ipv6_address=self.ipv6_address,
            ipv6_address_private=self.ipv6_address_private,
            locked=self.locked,
            memory=self.memory,
            monitoring=self.monitoring,
            name=self.name,
            price_hourly=self.price_hourly,
            price_monthly=self.price_monthly,
            private_networking=self.private_networking,
            region=self.region,
            size=self.size,
            status=self.status,
            tag=self.tag,
            tags=self.tags,
            urn=self.urn,
            vcpus=self.vcpus,
            volume_ids=self.volume_ids,
            vpc_uuid=self.vpc_uuid)


def get_droplet(gpu: Optional[_builtins.bool] = None,
                id: Optional[_builtins.int] = None,
                name: Optional[_builtins.str] = None,
                tag: Optional[_builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDropletResult:
    """
    Get information on a Droplet for use in other resources. This data source provides
    all of the Droplet's properties as configured on your DigitalOcean account. This
    is useful if the Droplet in question is not managed by this provider or you need to
    utilize any of the Droplet's data.

    **Note:** This data source returns a single Droplet. When specifying a `tag`, an
    error is triggered if more than one Droplet is found.

    ## Example Usage

    Get the Droplet by name:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_droplet(name="web")
    pulumi.export("dropletOutput", example.ipv4_address)
    ```

    Get the Droplet by tag:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_droplet(tag="web")
    ```

    Get the Droplet by ID:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_droplet(id=example_digitalocean_kubernetes_cluster["nodePool"][0]["nodes"][0]["dropletId"])
    ```


    :param _builtins.bool gpu: A boolean value specifying whether or not to search GPU Droplets
    :param _builtins.int id: The ID of the Droplet
    :param _builtins.str name: The name of the Droplet.
    :param _builtins.str tag: A tag applied to the Droplet.
           
           To include GPU Droplets when searching by name, use:
    """
    __args__ = dict()
    __args__['gpu'] = gpu
    __args__['id'] = id
    __args__['name'] = name
    __args__['tag'] = tag
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getDroplet:getDroplet', __args__, opts=opts, typ=GetDropletResult).value

    return AwaitableGetDropletResult(
        backups=pulumi.get(__ret__, 'backups'),
        created_at=pulumi.get(__ret__, 'created_at'),
        disk=pulumi.get(__ret__, 'disk'),
        gpu=pulumi.get(__ret__, 'gpu'),
        id=pulumi.get(__ret__, 'id'),
        image=pulumi.get(__ret__, 'image'),
        ipv4_address=pulumi.get(__ret__, 'ipv4_address'),
        ipv4_address_private=pulumi.get(__ret__, 'ipv4_address_private'),
        ipv6=pulumi.get(__ret__, 'ipv6'),
        ipv6_address=pulumi.get(__ret__, 'ipv6_address'),
        ipv6_address_private=pulumi.get(__ret__, 'ipv6_address_private'),
        locked=pulumi.get(__ret__, 'locked'),
        memory=pulumi.get(__ret__, 'memory'),
        monitoring=pulumi.get(__ret__, 'monitoring'),
        name=pulumi.get(__ret__, 'name'),
        price_hourly=pulumi.get(__ret__, 'price_hourly'),
        price_monthly=pulumi.get(__ret__, 'price_monthly'),
        private_networking=pulumi.get(__ret__, 'private_networking'),
        region=pulumi.get(__ret__, 'region'),
        size=pulumi.get(__ret__, 'size'),
        status=pulumi.get(__ret__, 'status'),
        tag=pulumi.get(__ret__, 'tag'),
        tags=pulumi.get(__ret__, 'tags'),
        urn=pulumi.get(__ret__, 'urn'),
        vcpus=pulumi.get(__ret__, 'vcpus'),
        volume_ids=pulumi.get(__ret__, 'volume_ids'),
        vpc_uuid=pulumi.get(__ret__, 'vpc_uuid'))
def get_droplet_output(gpu: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                       id: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                       name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       tag: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDropletResult]:
    """
    Get information on a Droplet for use in other resources. This data source provides
    all of the Droplet's properties as configured on your DigitalOcean account. This
    is useful if the Droplet in question is not managed by this provider or you need to
    utilize any of the Droplet's data.

    **Note:** This data source returns a single Droplet. When specifying a `tag`, an
    error is triggered if more than one Droplet is found.

    ## Example Usage

    Get the Droplet by name:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_droplet(name="web")
    pulumi.export("dropletOutput", example.ipv4_address)
    ```

    Get the Droplet by tag:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_droplet(tag="web")
    ```

    Get the Droplet by ID:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_droplet(id=example_digitalocean_kubernetes_cluster["nodePool"][0]["nodes"][0]["dropletId"])
    ```


    :param _builtins.bool gpu: A boolean value specifying whether or not to search GPU Droplets
    :param _builtins.int id: The ID of the Droplet
    :param _builtins.str name: The name of the Droplet.
    :param _builtins.str tag: A tag applied to the Droplet.
           
           To include GPU Droplets when searching by name, use:
    """
    __args__ = dict()
    __args__['gpu'] = gpu
    __args__['id'] = id
    __args__['name'] = name
    __args__['tag'] = tag
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getDroplet:getDroplet', __args__, opts=opts, typ=GetDropletResult)
    return __ret__.apply(lambda __response__: GetDropletResult(
        backups=pulumi.get(__response__, 'backups'),
        created_at=pulumi.get(__response__, 'created_at'),
        disk=pulumi.get(__response__, 'disk'),
        gpu=pulumi.get(__response__, 'gpu'),
        id=pulumi.get(__response__, 'id'),
        image=pulumi.get(__response__, 'image'),
        ipv4_address=pulumi.get(__response__, 'ipv4_address'),
        ipv4_address_private=pulumi.get(__response__, 'ipv4_address_private'),
        ipv6=pulumi.get(__response__, 'ipv6'),
        ipv6_address=pulumi.get(__response__, 'ipv6_address'),
        ipv6_address_private=pulumi.get(__response__, 'ipv6_address_private'),
        locked=pulumi.get(__response__, 'locked'),
        memory=pulumi.get(__response__, 'memory'),
        monitoring=pulumi.get(__response__, 'monitoring'),
        name=pulumi.get(__response__, 'name'),
        price_hourly=pulumi.get(__response__, 'price_hourly'),
        price_monthly=pulumi.get(__response__, 'price_monthly'),
        private_networking=pulumi.get(__response__, 'private_networking'),
        region=pulumi.get(__response__, 'region'),
        size=pulumi.get(__response__, 'size'),
        status=pulumi.get(__response__, 'status'),
        tag=pulumi.get(__response__, 'tag'),
        tags=pulumi.get(__response__, 'tags'),
        urn=pulumi.get(__response__, 'urn'),
        vcpus=pulumi.get(__response__, 'vcpus'),
        volume_ids=pulumi.get(__response__, 'volume_ids'),
        vpc_uuid=pulumi.get(__response__, 'vpc_uuid')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetSshKeyResult',
    'AwaitableGetSshKeyResult',
    'get_ssh_key',
    'get_ssh_key_output',
]

@pulumi.output_type
class GetSshKeyResult:
    """
    A collection of values returned by getSshKey.
    """
    def __init__(__self__, fingerprint=None, id=None, name=None, public_key=None):
        if fingerprint and not isinstance(fingerprint, str):
            raise TypeError("Expected argument 'fingerprint' to be a str")
        pulumi.set(__self__, "fingerprint", fingerprint)
        if id and not isinstance(id, int):
            raise TypeError("Expected argument 'id' to be a int")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if public_key and not isinstance(public_key, str):
            raise TypeError("Expected argument 'public_key' to be a str")
        pulumi.set(__self__, "public_key", public_key)

    @_builtins.property
    @pulumi.getter
    def fingerprint(self) -> _builtins.str:
        """
        The fingerprint of the public key of the ssh key.
        """
        return pulumi.get(self, "fingerprint")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.int:
        """
        The ID of the ssh key.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="publicKey")
    def public_key(self) -> _builtins.str:
        """
        The public key of the ssh key.
        """
        return pulumi.get(self, "public_key")


class AwaitableGetSshKeyResult(GetSshKeyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSshKeyResult(
            fingerprint=self.fingerprint,
            id=self.id,
            name=self.name,
            public_key=self.public_key)


def get_ssh_key(name: Optional[_builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSshKeyResult:
    """
    Get information on a ssh key. This data source provides the name, public key,
    and fingerprint as configured on your DigitalOcean account. This is useful if
    the ssh key in question is not managed by the provider or you need to utilize any
    of the keys data.

    An error is triggered if the provided ssh key name does not exist.

    ## Example Usage

    Get the ssh key:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_ssh_key(name="example")
    example_droplet = digitalocean.Droplet("example",
        image="ubuntu-18-04-x64",
        name="example-1",
        region=digitalocean.Region.NYC2,
        size=digitalocean.DropletSlug.DROPLET_S1_VCPU1_GB,
        ssh_keys=[example.id])
    ```


    :param _builtins.str name: The name of the ssh key.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('digitalocean:index/getSshKey:getSshKey', __args__, opts=opts, typ=GetSshKeyResult).value

    return AwaitableGetSshKeyResult(
        fingerprint=pulumi.get(__ret__, 'fingerprint'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        public_key=pulumi.get(__ret__, 'public_key'))
def get_ssh_key_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetSshKeyResult]:
    """
    Get information on a ssh key. This data source provides the name, public key,
    and fingerprint as configured on your DigitalOcean account. This is useful if
    the ssh key in question is not managed by the provider or you need to utilize any
    of the keys data.

    An error is triggered if the provided ssh key name does not exist.

    ## Example Usage

    Get the ssh key:

    ```python
    import pulumi
    import pulumi_digitalocean as digitalocean

    example = digitalocean.get_ssh_key(name="example")
    example_droplet = digitalocean.Droplet("example",
        image="ubuntu-18-04-x64",
        name="example-1",
        region=digitalocean.Region.NYC2,
        size=digitalocean.DropletSlug.DROPLET_S1_VCPU1_GB,
        ssh_keys=[example.id])
    ```


    :param _builtins.str name: The name of the ssh key.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('digitalocean:index/getSshKey:getSshKey', __args__, opts=opts, typ=GetSshKeyResult)
    return __ret__.apply(lambda __response__: GetSshKeyResult(
        fingerprint=pulumi.get(__response__, 'fingerprint'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        public_key=pulumi.get(__response__, 'public_key')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GenaiKnowledgeBaseArgs', 'GenaiKnowledgeBase']

@pulumi.input_type
class GenaiKnowledgeBaseArgs:
    def __init__(__self__, *,
                 datasources: pulumi.Input[Sequence[pulumi.Input['GenaiKnowledgeBaseDataSourceArgs']]],
                 embedding_model_uuid: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 region: pulumi.Input[_builtins.str],
                 added_to_agent_at: Optional[pulumi.Input[_builtins.str]] = None,
                 database_id: Optional[pulumi.Input[_builtins.str]] = None,
                 is_public: Optional[pulumi.Input[_builtins.bool]] = None,
                 last_indexing_jobs: Optional[pulumi.Input[Sequence[pulumi.Input['GenaiKnowledgeBaseLastIndexingJobArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 vpc_uuid: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a GenaiKnowledgeBase resource.
        :param pulumi.Input[Sequence[pulumi.Input['GenaiKnowledgeBaseDataSourceArgs']]] datasources: Data sources for the knowledge base
        :param pulumi.Input[_builtins.str] embedding_model_uuid: The unique identifier of the embedding model
        :param pulumi.Input[_builtins.str] project_id: The unique identifier of the project to which the knowledge base belongs.
        :param pulumi.Input[_builtins.str] added_to_agent_at: The time when the knowledge base was added to the agent.
        :param pulumi.Input[_builtins.str] database_id: The unique identifier of the DigitalOcean OpenSearch database this knowledge base will use
        :param pulumi.Input[_builtins.bool] is_public: Indicates whether the knowledge base is public or private.
        :param pulumi.Input[Sequence[pulumi.Input['GenaiKnowledgeBaseLastIndexingJobArgs']]] last_indexing_jobs: The last indexing job for the knowledge base.
        :param pulumi.Input[_builtins.str] name: The name of the knowledge base.
        :param pulumi.Input[_builtins.str] vpc_uuid: The unique identifier of the VPC to which the knowledge base belongs.
        """
        pulumi.set(__self__, "datasources", datasources)
        pulumi.set(__self__, "embedding_model_uuid", embedding_model_uuid)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "region", region)
        if added_to_agent_at is not None:
            pulumi.set(__self__, "added_to_agent_at", added_to_agent_at)
        if database_id is not None:
            pulumi.set(__self__, "database_id", database_id)
        if is_public is not None:
            pulumi.set(__self__, "is_public", is_public)
        if last_indexing_jobs is not None:
            pulumi.set(__self__, "last_indexing_jobs", last_indexing_jobs)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpc_uuid is not None:
            pulumi.set(__self__, "vpc_uuid", vpc_uuid)

    @_builtins.property
    @pulumi.getter
    def datasources(self) -> pulumi.Input[Sequence[pulumi.Input['GenaiKnowledgeBaseDataSourceArgs']]]:
        """
        Data sources for the knowledge base
        """
        return pulumi.get(self, "datasources")

    @datasources.setter
    def datasources(self, value: pulumi.Input[Sequence[pulumi.Input['GenaiKnowledgeBaseDataSourceArgs']]]):
        pulumi.set(self, "datasources", value)

    @_builtins.property
    @pulumi.getter(name="embeddingModelUuid")
    def embedding_model_uuid(self) -> pulumi.Input[_builtins.str]:
        """
        The unique identifier of the embedding model
        """
        return pulumi.get(self, "embedding_model_uuid")

    @embedding_model_uuid.setter
    def embedding_model_uuid(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "embedding_model_uuid", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        The unique identifier of the project to which the knowledge base belongs.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="addedToAgentAt")
    def added_to_agent_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The time when the knowledge base was added to the agent.
        """
        return pulumi.get(self, "added_to_agent_at")

    @added_to_agent_at.setter
    def added_to_agent_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "added_to_agent_at", value)

    @_builtins.property
    @pulumi.getter(name="databaseId")
    def database_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the DigitalOcean OpenSearch database this knowledge base will use
        """
        return pulumi.get(self, "database_id")

    @database_id.setter
    def database_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "database_id", value)

    @_builtins.property
    @pulumi.getter(name="isPublic")
    def is_public(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the knowledge base is public or private.
        """
        return pulumi.get(self, "is_public")

    @is_public.setter
    def is_public(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_public", value)

    @_builtins.property
    @pulumi.getter(name="lastIndexingJobs")
    def last_indexing_jobs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GenaiKnowledgeBaseLastIndexingJobArgs']]]]:
        """
        The last indexing job for the knowledge base.
        """
        return pulumi.get(self, "last_indexing_jobs")

    @last_indexing_jobs.setter
    def last_indexing_jobs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GenaiKnowledgeBaseLastIndexingJobArgs']]]]):
        pulumi.set(self, "last_indexing_jobs", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the knowledge base.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="vpcUuid")
    def vpc_uuid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the VPC to which the knowledge base belongs.
        """
        return pulumi.get(self, "vpc_uuid")

    @vpc_uuid.setter
    def vpc_uuid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vpc_uuid", value)


@pulumi.input_type
class _GenaiKnowledgeBaseState:
    def __init__(__self__, *,
                 added_to_agent_at: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 database_id: Optional[pulumi.Input[_builtins.str]] = None,
                 datasources: Optional[pulumi.Input[Sequence[pulumi.Input['GenaiKnowledgeBaseDataSourceArgs']]]] = None,
                 embedding_model_uuid: Optional[pulumi.Input[_builtins.str]] = None,
                 is_public: Optional[pulumi.Input[_builtins.bool]] = None,
                 last_indexing_jobs: Optional[pulumi.Input[Sequence[pulumi.Input['GenaiKnowledgeBaseLastIndexingJobArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 vpc_uuid: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering GenaiKnowledgeBase resources.
        :param pulumi.Input[_builtins.str] added_to_agent_at: The time when the knowledge base was added to the agent.
        :param pulumi.Input[_builtins.str] created_at: The time when the knowledge base was created.
        :param pulumi.Input[_builtins.str] database_id: The unique identifier of the DigitalOcean OpenSearch database this knowledge base will use
        :param pulumi.Input[Sequence[pulumi.Input['GenaiKnowledgeBaseDataSourceArgs']]] datasources: Data sources for the knowledge base
        :param pulumi.Input[_builtins.str] embedding_model_uuid: The unique identifier of the embedding model
        :param pulumi.Input[_builtins.bool] is_public: Indicates whether the knowledge base is public or private.
        :param pulumi.Input[Sequence[pulumi.Input['GenaiKnowledgeBaseLastIndexingJobArgs']]] last_indexing_jobs: The last indexing job for the knowledge base.
        :param pulumi.Input[_builtins.str] name: The name of the knowledge base.
        :param pulumi.Input[_builtins.str] project_id: The unique identifier of the project to which the knowledge base belongs.
        :param pulumi.Input[_builtins.str] vpc_uuid: The unique identifier of the VPC to which the knowledge base belongs.
        """
        if added_to_agent_at is not None:
            pulumi.set(__self__, "added_to_agent_at", added_to_agent_at)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if database_id is not None:
            pulumi.set(__self__, "database_id", database_id)
        if datasources is not None:
            pulumi.set(__self__, "datasources", datasources)
        if embedding_model_uuid is not None:
            pulumi.set(__self__, "embedding_model_uuid", embedding_model_uuid)
        if is_public is not None:
            pulumi.set(__self__, "is_public", is_public)
        if last_indexing_jobs is not None:
            pulumi.set(__self__, "last_indexing_jobs", last_indexing_jobs)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if vpc_uuid is not None:
            pulumi.set(__self__, "vpc_uuid", vpc_uuid)

    @_builtins.property
    @pulumi.getter(name="addedToAgentAt")
    def added_to_agent_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The time when the knowledge base was added to the agent.
        """
        return pulumi.get(self, "added_to_agent_at")

    @added_to_agent_at.setter
    def added_to_agent_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "added_to_agent_at", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The time when the knowledge base was created.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="databaseId")
    def database_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the DigitalOcean OpenSearch database this knowledge base will use
        """
        return pulumi.get(self, "database_id")

    @database_id.setter
    def database_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "database_id", value)

    @_builtins.property
    @pulumi.getter
    def datasources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GenaiKnowledgeBaseDataSourceArgs']]]]:
        """
        Data sources for the knowledge base
        """
        return pulumi.get(self, "datasources")

    @datasources.setter
    def datasources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GenaiKnowledgeBaseDataSourceArgs']]]]):
        pulumi.set(self, "datasources", value)

    @_builtins.property
    @pulumi.getter(name="embeddingModelUuid")
    def embedding_model_uuid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the embedding model
        """
        return pulumi.get(self, "embedding_model_uuid")

    @embedding_model_uuid.setter
    def embedding_model_uuid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "embedding_model_uuid", value)

    @_builtins.property
    @pulumi.getter(name="isPublic")
    def is_public(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates whether the knowledge base is public or private.
        """
        return pulumi.get(self, "is_public")

    @is_public.setter
    def is_public(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_public", value)

    @_builtins.property
    @pulumi.getter(name="lastIndexingJobs")
    def last_indexing_jobs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GenaiKnowledgeBaseLastIndexingJobArgs']]]]:
        """
        The last indexing job for the knowledge base.
        """
        return pulumi.get(self, "last_indexing_jobs")

    @last_indexing_jobs.setter
    def last_indexing_jobs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GenaiKnowledgeBaseLastIndexingJobArgs']]]]):
        pulumi.set(self, "last_indexing_jobs", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the knowledge base.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the project to which the knowledge base belongs.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="vpcUuid")
    def vpc_uuid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique identifier of the VPC to which the knowledge base belongs.
        """
        return pulumi.get(self, "vpc_uuid")

    @vpc_uuid.setter
    def vpc_uuid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "vpc_uuid", value)


@pulumi.type_token("digitalocean:index/genaiKnowledgeBase:GenaiKnowledgeBase")
class GenaiKnowledgeBase(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 added_to_agent_at: Optional[pulumi.Input[_builtins.str]] = None,
                 database_id: Optional[pulumi.Input[_builtins.str]] = None,
                 datasources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GenaiKnowledgeBaseDataSourceArgs', 'GenaiKnowledgeBaseDataSourceArgsDict']]]]] = None,
                 embedding_model_uuid: Optional[pulumi.Input[_builtins.str]] = None,
                 is_public: Optional[pulumi.Input[_builtins.bool]] = None,
                 last_indexing_jobs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GenaiKnowledgeBaseLastIndexingJobArgs', 'GenaiKnowledgeBaseLastIndexingJobArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 vpc_uuid: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Create a GenaiKnowledgeBase resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] added_to_agent_at: The time when the knowledge base was added to the agent.
        :param pulumi.Input[_builtins.str] database_id: The unique identifier of the DigitalOcean OpenSearch database this knowledge base will use
        :param pulumi.Input[Sequence[pulumi.Input[Union['GenaiKnowledgeBaseDataSourceArgs', 'GenaiKnowledgeBaseDataSourceArgsDict']]]] datasources: Data sources for the knowledge base
        :param pulumi.Input[_builtins.str] embedding_model_uuid: The unique identifier of the embedding model
        :param pulumi.Input[_builtins.bool] is_public: Indicates whether the knowledge base is public or private.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GenaiKnowledgeBaseLastIndexingJobArgs', 'GenaiKnowledgeBaseLastIndexingJobArgsDict']]]] last_indexing_jobs: The last indexing job for the knowledge base.
        :param pulumi.Input[_builtins.str] name: The name of the knowledge base.
        :param pulumi.Input[_builtins.str] project_id: The unique identifier of the project to which the knowledge base belongs.
        :param pulumi.Input[_builtins.str] vpc_uuid: The unique identifier of the VPC to which the knowledge base belongs.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GenaiKnowledgeBaseArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a GenaiKnowledgeBase resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param GenaiKnowledgeBaseArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GenaiKnowledgeBaseArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 added_to_agent_at: Optional[pulumi.Input[_builtins.str]] = None,
                 database_id: Optional[pulumi.Input[_builtins.str]] = None,
                 datasources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GenaiKnowledgeBaseDataSourceArgs', 'GenaiKnowledgeBaseDataSourceArgsDict']]]]] = None,
                 embedding_model_uuid: Optional[pulumi.Input[_builtins.str]] = None,
                 is_public: Optional[pulumi.Input[_builtins.bool]] = None,
                 last_indexing_jobs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GenaiKnowledgeBaseLastIndexingJobArgs', 'GenaiKnowledgeBaseLastIndexingJobArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 vpc_uuid: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GenaiKnowledgeBaseArgs.__new__(GenaiKnowledgeBaseArgs)

            __props__.__dict__["added_to_agent_at"] = added_to_agent_at
            __props__.__dict__["database_id"] = database_id
            if datasources is None and not opts.urn:
                raise TypeError("Missing required property 'datasources'")
            __props__.__dict__["datasources"] = datasources
            if embedding_model_uuid is None and not opts.urn:
                raise TypeError("Missing required property 'embedding_model_uuid'")
            __props__.__dict__["embedding_model_uuid"] = embedding_model_uuid
            __props__.__dict__["is_public"] = is_public
            __props__.__dict__["last_indexing_jobs"] = last_indexing_jobs
            __props__.__dict__["name"] = name
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            if region is None and not opts.urn:
                raise TypeError("Missing required property 'region'")
            __props__.__dict__["region"] = region
            __props__.__dict__["tags"] = tags
            __props__.__dict__["vpc_uuid"] = vpc_uuid
            __props__.__dict__["created_at"] = None
        super(GenaiKnowledgeBase, __self__).__init__(
            'digitalocean:index/genaiKnowledgeBase:GenaiKnowledgeBase',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            added_to_agent_at: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            database_id: Optional[pulumi.Input[_builtins.str]] = None,
            datasources: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GenaiKnowledgeBaseDataSourceArgs', 'GenaiKnowledgeBaseDataSourceArgsDict']]]]] = None,
            embedding_model_uuid: Optional[pulumi.Input[_builtins.str]] = None,
            is_public: Optional[pulumi.Input[_builtins.bool]] = None,
            last_indexing_jobs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GenaiKnowledgeBaseLastIndexingJobArgs', 'GenaiKnowledgeBaseLastIndexingJobArgsDict']]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            vpc_uuid: Optional[pulumi.Input[_builtins.str]] = None) -> 'GenaiKnowledgeBase':
        """
        Get an existing GenaiKnowledgeBase resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] added_to_agent_at: The time when the knowledge base was added to the agent.
        :param pulumi.Input[_builtins.str] created_at: The time when the knowledge base was created.
        :param pulumi.Input[_builtins.str] database_id: The unique identifier of the DigitalOcean OpenSearch database this knowledge base will use
        :param pulumi.Input[Sequence[pulumi.Input[Union['GenaiKnowledgeBaseDataSourceArgs', 'GenaiKnowledgeBaseDataSourceArgsDict']]]] datasources: Data sources for the knowledge base
        :param pulumi.Input[_builtins.str] embedding_model_uuid: The unique identifier of the embedding model
        :param pulumi.Input[_builtins.bool] is_public: Indicates whether the knowledge base is public or private.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GenaiKnowledgeBaseLastIndexingJobArgs', 'GenaiKnowledgeBaseLastIndexingJobArgsDict']]]] last_indexing_jobs: The last indexing job for the knowledge base.
        :param pulumi.Input[_builtins.str] name: The name of the knowledge base.
        :param pulumi.Input[_builtins.str] project_id: The unique identifier of the project to which the knowledge base belongs.
        :param pulumi.Input[_builtins.str] vpc_uuid: The unique identifier of the VPC to which the knowledge base belongs.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GenaiKnowledgeBaseState.__new__(_GenaiKnowledgeBaseState)

        __props__.__dict__["added_to_agent_at"] = added_to_agent_at
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["database_id"] = database_id
        __props__.__dict__["datasources"] = datasources
        __props__.__dict__["embedding_model_uuid"] = embedding_model_uuid
        __props__.__dict__["is_public"] = is_public
        __props__.__dict__["last_indexing_jobs"] = last_indexing_jobs
        __props__.__dict__["name"] = name
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["region"] = region
        __props__.__dict__["tags"] = tags
        __props__.__dict__["vpc_uuid"] = vpc_uuid
        return GenaiKnowledgeBase(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="addedToAgentAt")
    def added_to_agent_at(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The time when the knowledge base was added to the agent.
        """
        return pulumi.get(self, "added_to_agent_at")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The time when the knowledge base was created.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="databaseId")
    def database_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The unique identifier of the DigitalOcean OpenSearch database this knowledge base will use
        """
        return pulumi.get(self, "database_id")

    @_builtins.property
    @pulumi.getter
    def datasources(self) -> pulumi.Output[Sequence['outputs.GenaiKnowledgeBaseDataSource']]:
        """
        Data sources for the knowledge base
        """
        return pulumi.get(self, "datasources")

    @_builtins.property
    @pulumi.getter(name="embeddingModelUuid")
    def embedding_model_uuid(self) -> pulumi.Output[_builtins.str]:
        """
        The unique identifier of the embedding model
        """
        return pulumi.get(self, "embedding_model_uuid")

    @_builtins.property
    @pulumi.getter(name="isPublic")
    def is_public(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates whether the knowledge base is public or private.
        """
        return pulumi.get(self, "is_public")

    @_builtins.property
    @pulumi.getter(name="lastIndexingJobs")
    def last_indexing_jobs(self) -> pulumi.Output[Optional[Sequence['outputs.GenaiKnowledgeBaseLastIndexingJob']]]:
        """
        The last indexing job for the knowledge base.
        """
        return pulumi.get(self, "last_indexing_jobs")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the knowledge base.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The unique identifier of the project to which the knowledge base belongs.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="vpcUuid")
    def vpc_uuid(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The unique identifier of the VPC to which the knowledge base belongs.
        """
        return pulumi.get(self, "vpc_uuid")

